@@ -29,6 +29,7 @@ import java.security.PrivilegedExceptionAction;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -760,13 +761,6 @@ public class TezClientUtils {
   
   static void maybeAddDefaultLoggingJavaOpts(String logLevel, List<String> vargs) {
     Objects.requireNonNull(vargs);
-    if (!vargs.isEmpty()) {
-      for (String arg : vargs) {
-        if (arg.contains(TezConstants.TEZ_ROOT_LOGGER_NAME)) {
-          return;
-        }
-      }
-    }
     TezClientUtils.addLog4jSystemProperties(logLevel, vargs);
   }
 
@@ -774,7 +768,7 @@ public class TezClientUtils {
   public static String maybeAddDefaultLoggingJavaOpts(String logLevel, String javaOpts) {
     List<String> vargs = new ArrayList<String>(5);
     if (javaOpts != null) {
-      vargs.add(javaOpts);
+      Collections.addAll(vargs, javaOpts.split(" "));
     } else {
       vargs.add("");
     }
@@ -829,8 +823,19 @@ public class TezClientUtils {
         + TezConstants.TEZ_CONTAINER_LOG4J_PROPERTIES_FILE);
     vargs.add("-D" + YarnConfiguration.YARN_APP_CONTAINER_LOG_DIR + "="
         + ApplicationConstants.LOG_DIR_EXPANSION_VAR);
-    vargs.add("-D" + TezConstants.TEZ_ROOT_LOGGER_NAME + "=" + logLevel
-        + "," + TezConstants.TEZ_CONTAINER_LOGGER_NAME);
+    boolean isRootLoggerPresent = false;
+    String rootLoggerArg = "-D" + TezConstants.TEZ_ROOT_LOGGER_NAME + "=" + logLevel
+        + "," + TezConstants.TEZ_CONTAINER_LOGGER_NAME;
+    for (int i = 0; i < vargs.size(); i++) {
+      String arg = vargs.get(i);
+      if (arg.contains(TezConstants.TEZ_ROOT_LOGGER_NAME)) {
+        vargs.set(i, rootLoggerArg);
+        isRootLoggerPresent = true;
+      }
+    }
+    if (!isRootLoggerPresent) {
+      vargs.add(rootLoggerArg);
+    }
   }
 
   static ConfigurationProto createFinalConfProtoForApp(Configuration amConf,
