@@ -22,10 +22,10 @@ import java.io.IOException;
 import java.nio.ByteBuffer;
 import java.util.ArrayList;
 import java.util.Collection;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.StringTokenizer;
+import java.util.stream.Collectors;
 import java.util.zip.Deflater;
 import java.util.zip.DeflaterOutputStream;
 import java.util.zip.Inflater;
@@ -291,7 +291,14 @@ public class TezCommonUtils {
    * @throws IOException
    */
   public static void mkDirForAM(FileSystem fs, Path dir) throws IOException {
-    fs.mkdirs(dir, new FsPermission(TEZ_AM_DIR_PERMISSION));
+    FsPermission perm = new FsPermission(TEZ_AM_DIR_PERMISSION);
+    fs.mkdirs(dir, perm);
+    if (!fs.getFileStatus(dir).getPermission().equals(perm)) {
+      LOG.warn("Directory " + dir.toString() + " created with unexpected permissions : "
+            + fs.getFileStatus(dir).getPermission() + ". Fixing permissions to correct value : "
+            + perm.toString());
+      fs.setPermission(dir, perm);
+    }
   }
 
   /**
@@ -405,20 +412,21 @@ public class TezCommonUtils {
   }
 
   public static String getCredentialsInfo(Credentials credentials, String identifier) {
+    if (credentials == null) {
+      return "Credentials: #" + identifier + "Tokens=null";
+    }
+
     StringBuilder sb = new StringBuilder();
     sb.append("Credentials: #" + identifier + "Tokens=").append(credentials.numberOfTokens());
     if (credentials.numberOfTokens() > 0) {
       sb.append(", Services=");
-      Iterator<Token<?>> tokenItr = credentials.getAllTokens().iterator();
-      if (tokenItr.hasNext()) {
-        Token token = tokenItr.next();
-        sb.append(token.getService()).append("(").append(token.getKind()).append(")");
+      sb.append(credentials.getAllTokens().stream()
+          .map(t -> String.format("%s(%s)", t.getService(), t.getKind()))
+          .collect(Collectors.joining(",")));
 
-      }
-      while(tokenItr.hasNext()) {
-        Token token = tokenItr.next();
-        sb.append(",").append(token.getService()).append("(").append(token.getKind()).append(")");
-      }
+      sb.append(", TokenDetails=");
+      sb.append(credentials.getAllTokens().stream().map(Token::toString)
+          .collect(Collectors.joining(",")));
     }
     return sb.toString();
   }
@@ -565,4 +573,10 @@ public class TezCommonUtils {
     return 1000l * timeoutSecs;
   }
 
+  public static int getJavaVersion() {
+    String javaVersionString = System.getProperty("java.version");
+    return javaVersionString.split("\\.")[0].equals("1")
+      ? Integer.parseInt(javaVersionString.split("\\.")[1]) // "1.8" -> 8
+      : Integer.parseInt(javaVersionString.split("\\.")[0]); // "9.x" -> 9, "11.x" -> 11
+  }
 }
