@@ -213,6 +213,9 @@ public class DAGClientTimelineImpl extends DAGClientInternal {
       httpClient.destroy();
       httpClient = null;
     }
+    if (timelineReaderStrategy != null) {
+      timelineReaderStrategy.close();
+    }
   }
 
   private DAGStatusProto.Builder parseDagStatus(JSONObject jsonRoot, Set<StatusGetOpts> statusOptions)
@@ -520,4 +523,9 @@ public class DAGClientTimelineImpl extends DAGClientInternal {
     return getDAGStatus(statusOptions);
   }
 
+  @Override
+  public String getWebUIAddress() throws IOException, TezException {
+    throw new TezException("DAGClientTimelineImpl.getWebUIAddress is not supported");
+  }
+
 }
