@@ -21,13 +21,16 @@ package org.apache.tez.dag.records;
 import java.io.DataInput;
 import java.io.DataOutput;
 import java.io.IOException;
+import java.util.Objects;
 
 import org.apache.hadoop.classification.InterfaceAudience;
 import org.apache.hadoop.classification.InterfaceStability;
 
-import com.google.common.base.Preconditions;
 import org.apache.tez.util.FastNumberFormat;
 
+import com.google.common.collect.Interner;
+import com.google.common.collect.Interners;
+
 /**
  * TezVertexID represents the immutable and unique identifier for
  * a Vertex in a Tez DAG. Each TezVertexID encompasses multiple Tez Tasks.
@@ -41,7 +44,7 @@ import org.apache.tez.util.FastNumberFormat;
  */
 @InterfaceAudience.Public
 @InterfaceStability.Stable
-public class TezVertexID extends TezID {
+public class TezVertexID extends TezID implements DAGIDAware {
   public static final String VERTEX = "vertex";
   static final ThreadLocal<FastNumberFormat> tezVertexIdFormat = new ThreadLocal<FastNumberFormat>() {
 
@@ -53,7 +56,7 @@ public class TezVertexID extends TezID {
     }
   };
 
-  private static TezIDCache<TezVertexID> tezVertexIDCache = new TezIDCache<>();
+  private static Interner<TezVertexID> tezVertexIDCache = Interners.newWeakInterner();
   private TezDAGID dagId;
 
   // Public for Writable serialization. Verify if this is actually required.
@@ -64,15 +67,11 @@ public class TezVertexID extends TezID {
    * Constructs a TezVertexID object from given {@link TezDAGID}.
    * @param dagId TezDAGID object for this TezVertexID
    * @param id the tip number
+   * @throws NullPointerException if {@code dagId} is {@code null}
    */
   public static TezVertexID getInstance(TezDAGID dagId, int id) {
-    Preconditions.checkArgument(dagId != null, "DagID cannot be null");
-    return tezVertexIDCache.getInstance(new TezVertexID(dagId, id));
-  }
-
-  @InterfaceAudience.Private
-  public static void clearCache() {
-    tezVertexIDCache.clear();
+    Objects.requireNonNull(dagId, "DagID cannot be null");
+    return tezVertexIDCache.intern(new TezVertexID(dagId, id));
   }
 
   private TezVertexID(TezDAGID dagId, int id) {
@@ -81,7 +80,8 @@ public class TezVertexID extends TezID {
   }
 
   /** Returns the {@link TezDAGID} object that this tip belongs to */
-  public TezDAGID getDAGId() {
+  @Override
+  public TezDAGID getDAGID() {
     return dagId;
   }
 
@@ -160,5 +160,4 @@ public class TezVertexID extends TezID {
     }
     return null;
   }
-
 }
