@@ -20,8 +20,8 @@ import java.net.URISyntaxException;
 import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
+import java.util.Objects;
 
-import com.google.common.base.Preconditions;
 import com.google.common.collect.Maps;
 import org.apache.hadoop.classification.InterfaceAudience;
 import org.apache.hadoop.conf.Configuration;
@@ -104,6 +104,7 @@ public class TezTaskCommunicatorImpl extends TaskCommunicator {
     Credentials credentials = null;
     boolean credentialsChanged = false;
     boolean taskPulled = false;
+    long usedMemory = 0;
 
     void reset() {
       taskSpec = null;
@@ -221,8 +222,9 @@ public class TezTaskCommunicatorImpl extends TaskCommunicator {
                                          int priority) {
 
     ContainerInfo containerInfo = registeredContainers.get(containerId);
-    Preconditions.checkNotNull(containerInfo, "Cannot register task attempt %s to unknown container %s",
-        taskSpec.getTaskAttemptID(), containerId);
+    Objects.requireNonNull(containerInfo,
+        String.format("Cannot register task attempt %s to unknown container %s",
+            taskSpec.getTaskAttemptID(), containerId));
     synchronized (containerInfo) {
       if (containerInfo.taskSpec != null) {
         throw new TezUncheckedException(
@@ -309,18 +311,14 @@ public class TezTaskCommunicatorImpl extends TaskCommunicator {
       } else {
         ContainerId containerId = ConverterUtils.toContainerId(containerContext
             .getContainerIdentifier());
-        if (LOG.isDebugEnabled()) {
-          LOG.debug("Container with id: " + containerId + " asked for a task");
-        }
+        LOG.debug("Container with id: {} asked for a task", containerId);
         task = getContainerTask(containerId);
         if (task != null && !task.shouldDie()) {
           getContext().taskSubmitted(task.getTaskSpec().getTaskAttemptID(), containerId);
           getContext().taskStartedRemotely(task.getTaskSpec().getTaskAttemptID());
         }
       }
-      if (LOG.isDebugEnabled()) {
-        LOG.debug("getTask returning task: " + task);
-      }
+      LOG.debug("getTask returning task: {}", task);
       return task;
     }
 
@@ -334,10 +332,7 @@ public class TezTaskCommunicatorImpl extends TaskCommunicator {
         TezException {
       ContainerId containerId = ConverterUtils.toContainerId(request.getContainerIdentifier());
       long requestId = request.getRequestId();
-      if (LOG.isDebugEnabled()) {
-        LOG.debug("Received heartbeat from container"
-            + ", request=" + request);
-      }
+      LOG.debug("Received heartbeat from container, request={}", request);
 
       ContainerInfo containerInfo = registeredContainers.get(containerId);
       if (containerInfo == null) {
@@ -388,6 +383,7 @@ public class TezTaskCommunicatorImpl extends TaskCommunicator {
       response.setLastRequestId(requestId);
       containerInfo.lastRequestId = requestId;
       containerInfo.lastResponse = response;
+      containerInfo.usedMemory = request.getUsedMemory();
       return response;
     }
 
@@ -435,9 +431,7 @@ public class TezTaskCommunicatorImpl extends TaskCommunicator {
           }
         } else {
           task = null;
-          if (LOG.isDebugEnabled()) {
-            LOG.debug("No task assigned yet for running container: " + containerId);
-          }
+          LOG.debug("No task assigned yet for running container: {}", containerId);
         }
       }
     }
@@ -474,4 +468,8 @@ public class TezTaskCommunicatorImpl extends TaskCommunicator {
   protected ContainerId getContainerForAttempt(TezTaskAttemptID taskAttemptId) {
     return attemptToContainerMap.get(taskAttemptId);
   }
+
+  public long getTotalUsedMemory() {
+    return registeredContainers.values().stream().mapToLong(c -> c.usedMemory).sum();
+  }
 }
\ No newline at end of file
