@@ -19,7 +19,6 @@
 package org.apache.tez.dag.app.dag;
 
 import java.util.List;
-import java.util.Set;
 import java.util.concurrent.atomic.AtomicBoolean;
 
 import org.apache.hadoop.yarn.api.records.Container;
@@ -29,17 +28,15 @@ import org.apache.tez.common.counters.DAGCounter;
 import org.apache.tez.common.counters.TezCounters;
 import org.apache.tez.dag.api.oldrecords.TaskAttemptReport;
 import org.apache.tez.dag.api.oldrecords.TaskAttemptState;
+import org.apache.tez.dag.records.TaskAttemptIDAware;
 import org.apache.tez.dag.records.TaskAttemptTerminationCause;
-import org.apache.tez.dag.records.TezDAGID;
 import org.apache.tez.dag.records.TezTaskAttemptID;
-import org.apache.tez.dag.records.TezTaskID;
-import org.apache.tez.dag.records.TezVertexID;
 import org.apache.tez.runtime.api.impl.TezEvent;
 
 /**
  * Read only view of TaskAttempt.
  */
-public interface TaskAttempt {
+public interface TaskAttempt extends TaskAttemptIDAware {
 
   public static class TaskAttemptStatus {
     public TezTaskAttemptID id;
@@ -67,12 +64,8 @@ public interface TaskAttempt {
       }
     }
   }
-  
-  TezTaskAttemptID getID();
-  TezTaskID getTaskID();
-  TezVertexID getVertexID();
-  TezDAGID getDAGID();
-  
+
+  Task getTask();
   TaskAttemptReport getReport();
   List<String> getDiagnostics();
   TaskAttemptTerminationCause getTerminationCause();
@@ -136,9 +129,4 @@ public interface TaskAttempt {
    *  yet, returns 0.
    */
   long getFinishTime();
-
-  /**
-   * @return the set of nodes on which sibling attempts were running on.
-   */
-  Set<NodeId> getNodesWithSiblingRunningAttempts();
 }
