@@ -19,6 +19,8 @@
 package org.apache.tez.dag.app.dag.impl;
 
 import java.io.IOException;
+import java.lang.management.ManagementFactory;
+import java.lang.management.MemoryMXBean;
 import java.net.URL;
 import java.security.PrivilegedExceptionAction;
 import java.util.ArrayList;
@@ -49,6 +51,7 @@ import org.apache.tez.common.TezUtilsInternal;
 import org.apache.tez.common.counters.LimitExceededException;
 import org.apache.tez.dag.app.dag.event.DAGEventTerminateDag;
 import org.apache.tez.dag.app.dag.event.DiagnosableEvent;
+import org.apache.tez.runtime.library.common.shuffle.ShuffleUtils;
 import org.apache.tez.state.OnStateChangedCallback;
 import org.apache.tez.state.StateMachineTez;
 import org.slf4j.Logger;
@@ -244,6 +247,8 @@ public class DAGImpl implements org.apache.tez.dag.app.dag.DAG,
   private static final CommitCompletedTransition COMMIT_COMPLETED_TRANSITION =
       new CommitCompletedTransition();
 
+  private final MemoryMXBean memoryMXBean = ManagementFactory.getMemoryMXBean();
+
   protected static final
     StateMachineFactory<DAGImpl, DAGState, DAGEventType, DAGEvent>
        stateMachineFactory
@@ -940,6 +945,10 @@ public class DAGImpl implements org.apache.tez.dag.app.dag.DAG,
       if (statusOptions.contains(StatusGetOpts.GET_COUNTERS)) {
         status.setDAGCounters(getAllCounters());
       }
+      if (statusOptions.contains(StatusGetOpts.GET_MEMORY_USAGE)) {
+        status.setMemoryUsage(memoryMXBean.getHeapMemoryUsage().getUsed(),
+            taskCommunicatorManagerInterface.getTotalUsedMemory());
+      }
       return status;
     } finally {
       readLock.unlock();
@@ -1032,7 +1041,7 @@ public class DAGImpl implements org.apache.tez.dag.app.dag.DAG,
   }
   
   public TaskAttemptImpl getTaskAttempt(TezTaskAttemptID taId) {
-    return (TaskAttemptImpl) getVertex(taId.getTaskID().getVertexID()).getTask(taId.getTaskID())
+    return (TaskAttemptImpl) getVertex(taId.getVertexID()).getTask(taId.getTaskID())
         .getAttempt(taId);
   }
 
@@ -1198,7 +1207,7 @@ public class DAGImpl implements org.apache.tez.dag.app.dag.DAG,
    */
   public void handle(DAGEvent event) {
     if (LOG.isDebugEnabled()) {
-      LOG.debug("Processing DAGEvent " + event.getDAGId() + " of type "
+      LOG.debug("Processing DAGEvent " + event.getDAGID() + " of type "
           + event.getType() + " while in state " + getInternalState()
           + ". Event: " + event);
     }
@@ -1764,6 +1773,13 @@ public class DAGImpl implements org.apache.tez.dag.app.dag.DAG,
 
     vertex.setInputVertices(inVertices);
     vertex.setOutputVertices(outVertices);
+    boolean cleanupShuffleDataAtVertexLevel = dag.dagConf.getInt(TezConfiguration.TEZ_AM_VERTEX_CLEANUP_HEIGHT,
+        TezConfiguration.TEZ_AM_VERTEX_CLEANUP_HEIGHT_DEFAULT) > 0 && ShuffleUtils.isTezShuffleHandler(dag.dagConf);
+    if (cleanupShuffleDataAtVertexLevel) {
+      int deletionHeight = dag.dagConf.getInt(TezConfiguration.TEZ_AM_VERTEX_CLEANUP_HEIGHT,
+              TezConfiguration.TEZ_AM_VERTEX_CLEANUP_HEIGHT_DEFAULT);
+      ((VertexImpl) vertex).initShuffleDeletionContext(deletionHeight);
+    }
   }
 
   /**
