@@ -26,6 +26,7 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
+import java.util.concurrent.TimeUnit;
 import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
 
@@ -40,11 +41,11 @@ import org.apache.tez.dag.app.dag.event.TaskEventTASucceeded;
 import org.apache.tez.dag.app.rm.AMSchedulerEventTAStateUpdated;
 import org.apache.tez.runtime.api.TaskFailureType;
 import org.apache.tez.serviceplugins.api.TaskScheduler;
+import org.apache.tez.util.StringInterner;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.net.NetUtils;
-import org.apache.hadoop.util.StringInterner;
 import org.apache.hadoop.yarn.api.records.Container;
 import org.apache.hadoop.yarn.api.records.ContainerId;
 import org.apache.hadoop.yarn.api.records.NodeId;
@@ -76,6 +77,7 @@ import org.apache.tez.dag.app.TaskHeartbeatHandler;
 import org.apache.tez.dag.app.dag.TaskAttempt;
 import org.apache.tez.dag.app.dag.TaskAttemptStateInternal;
 import org.apache.tez.dag.app.dag.Vertex;
+import org.apache.tez.dag.app.dag.Task;
 import org.apache.tez.dag.app.dag.event.DAGEvent;
 import org.apache.tez.dag.app.dag.event.DAGEventCounterUpdate;
 import org.apache.tez.dag.app.dag.event.DAGEventDiagnosticsUpdate;
@@ -102,10 +104,7 @@ import org.apache.tez.dag.history.DAGHistoryEvent;
 import org.apache.tez.dag.history.events.TaskAttemptFinishedEvent;
 import org.apache.tez.dag.history.events.TaskAttemptStartedEvent;
 import org.apache.tez.dag.records.TaskAttemptTerminationCause;
-import org.apache.tez.dag.records.TezDAGID;
 import org.apache.tez.dag.records.TezTaskAttemptID;
-import org.apache.tez.dag.records.TezTaskID;
-import org.apache.tez.dag.records.TezVertexID;
 import org.apache.tez.dag.recovery.records.RecoveryProtos.DataEventDependencyInfoProto;
 import org.apache.tez.runtime.api.events.InputFailedEvent;
 import org.apache.tez.runtime.api.events.InputReadErrorEvent;
@@ -117,7 +116,7 @@ import org.apache.tez.runtime.api.impl.TezEvent;
 import org.apache.tez.runtime.api.impl.EventMetaData.EventProducerConsumerType;
 
 import com.google.common.annotations.VisibleForTesting;
-import com.google.common.base.Preconditions;
+import org.apache.tez.common.Preconditions;
 import com.google.common.collect.Lists;
 import com.google.common.collect.Maps;
 
@@ -179,6 +178,12 @@ public class TaskAttemptImpl implements TaskAttempt,
   private TaskAttemptRecoveryData recoveryData;
   private long launchTime = 0;
   private long finishTime = 0;
+  /** System.nanoTime for task launch time, if recorded in this JVM. */
+  private Long launchTimeNs;
+  /** System.nanoTime for task finish time, if recorded in this JVM. */
+  private Long finishTimeNs;
+  /** Whether the task was recovered from a prior AM; see getDurationNs. */
+  private boolean isRecoveredDuration;
   private String trackerName;
   private int httpPort;
 
@@ -186,11 +191,12 @@ public class TaskAttemptImpl implements TaskAttempt,
   private Container container;
   private long allocationTime;
   private ContainerId containerId;
-  private NodeId containerNodeId;
+  protected NodeId containerNodeId;
   private String nodeHttpAddress;
   private String nodeRackName;
   
   private final Vertex vertex;
+  private final Task task;
   private final TaskLocationHint locationHint;
   private final TaskSpec taskSpec;
 
@@ -221,12 +227,6 @@ public class TaskAttemptImpl implements TaskAttempt,
   private final boolean leafVertex;
   
   private TezTaskAttemptID creationCausalTA;
-  // Record the set of nodes on which sibling attempts were running on, at the time of
-  // this attempt being scheduled. This set is empty for original task attempt, and
-  // non-empty when current task attempt is a speculative one, in which case scheduler
-  // should try to schedule the speculative attempt on to a node other than the one(s)
-  // recorded in this set.
-  private Set<NodeId> nodesWithSiblingRunningAttempts;
   private long creationTime;
   private long scheduledTime;
 
@@ -536,10 +536,10 @@ public class TaskAttemptImpl implements TaskAttempt,
       TaskHeartbeatHandler taskHeartbeatHandler, AppContext appContext,
       boolean isRescheduled,
       Resource resource, ContainerContext containerContext, boolean leafVertex,
-      Vertex vertex, TaskLocationHint locationHint, TaskSpec taskSpec) {
+      Task task, TaskLocationHint locationHint, TaskSpec taskSpec) {
     this(attemptId, eventHandler, taskCommunicatorManagerInterface, conf, clock,
         taskHeartbeatHandler, appContext, isRescheduled, resource, containerContext, leafVertex,
-        vertex, locationHint, taskSpec, null, null);
+        task, locationHint, taskSpec, null);
   }
 
   @SuppressWarnings("rawtypes")
@@ -548,8 +548,8 @@ public class TaskAttemptImpl implements TaskAttempt,
       TaskHeartbeatHandler taskHeartbeatHandler, AppContext appContext,
       boolean isRescheduled,
       Resource resource, ContainerContext containerContext, boolean leafVertex,
-      Vertex vertex, TaskLocationHint locationHint, TaskSpec taskSpec,
-      TezTaskAttemptID schedulingCausalTA, Set<NodeId> nodesWithSiblingRunningAttempts) {
+      Task task, TaskLocationHint locationHint, TaskSpec taskSpec,
+      TezTaskAttemptID schedulingCausalTA) {
 
     ReentrantReadWriteLock rwLock = new ReentrantReadWriteLock();
     this.readLock = rwLock.readLock();
@@ -561,11 +561,11 @@ public class TaskAttemptImpl implements TaskAttempt,
     this.clock = clock;
     this.taskHeartbeatHandler = taskHeartbeatHandler;
     this.appContext = appContext;
-    this.vertex = vertex;
+    this.vertex = task.getVertex();
+    this.task = task;
     this.locationHint = locationHint;
     this.taskSpec = taskSpec;
     this.creationCausalTA = schedulingCausalTA;
-    this.nodesWithSiblingRunningAttempts = nodesWithSiblingRunningAttempts;
     this.creationTime = clock.getTime();
 
     this.reportedStatus = new TaskAttemptStatus(this.attemptId);
@@ -585,34 +585,14 @@ public class TaskAttemptImpl implements TaskAttempt,
   }
 
   @Override
-  public TezTaskAttemptID getID() {
+  public TezTaskAttemptID getTaskAttemptID() {
     return attemptId;
   }
 
-  @Override
-  public TezTaskID getTaskID() {
-    return attemptId.getTaskID();
-  }
-
-  @Override
-  public TezVertexID getVertexID() {
-    return attemptId.getTaskID().getVertexID();
-  }
-
-  @Override
-  public TezDAGID getDAGID() {
-    return getVertexID().getDAGId();
-  }
-  
   public TezTaskAttemptID getSchedulingCausalTA() {
     return creationCausalTA;
   }
 
-  @Override
-  public Set<NodeId> getNodesWithSiblingRunningAttempts() {
-    return nodesWithSiblingRunningAttempts;
-  }
-
   @Override
   public TaskAttemptReport getReport() {
     TaskAttemptReport result = Records.newRecord(TaskAttemptReport.class);
@@ -794,6 +774,25 @@ public class TaskAttemptImpl implements TaskAttempt,
     }
   }
 
+
+  /** @return task runtime duration in NS. */
+  public long getDurationNs() {
+    readLock.lock();
+    try {
+      if (isRecoveredDuration) {
+        // NS values are not mappable between JVMs (per documentation, at
+        // least), so just use the clock after recovery.
+        return TimeUnit.MILLISECONDS.toNanos(launchTime == 0 ? 0
+            : (finishTime == 0 ? clock.getTime() : finishTime) - launchTime);
+      } else {
+        long ft = (finishTimeNs == null ? System.nanoTime() : finishTimeNs);
+        return (launchTimeNs == null) ? 0 : (ft - launchTimeNs);
+      }
+    } finally {
+      readLock.unlock();
+    }
+  }
+
   public long getCreationTime() {
     readLock.lock();
     try {
@@ -840,7 +839,12 @@ public class TaskAttemptImpl implements TaskAttempt,
       readLock.unlock();
     }
   }
-  
+
+  @Override
+  public Task getTask() {
+    return task;
+  }
+
   Vertex getVertex() {
     return vertex;
   }
@@ -862,12 +866,12 @@ public class TaskAttemptImpl implements TaskAttempt,
         LOG.error("Can't handle this event at current state for "
             + this.attemptId, e);
         eventHandler.handle(new DAGEventDiagnosticsUpdate(
-            this.attemptId.getTaskID().getVertexID().getDAGId(),
+            getDAGID(),
             "Invalid event " + event.getType() +
             " on TaskAttempt " + this.attemptId));
         eventHandler.handle(
             new DAGEvent(
-                this.attemptId.getTaskID().getVertexID().getDAGId(),
+                getDAGID(),
                 DAGEventType.INTERNAL_ERROR)
             );
       } catch (RuntimeException e) {
@@ -875,13 +879,13 @@ public class TaskAttemptImpl implements TaskAttempt,
             + " at current state " + oldState + " for "
             + this.attemptId, e);
         eventHandler.handle(new DAGEventDiagnosticsUpdate(
-            this.attemptId.getTaskID().getVertexID().getDAGId(),
+            getDAGID(),
             "Uncaught exception when handling event " + event.getType()
                 + " on TaskAttempt " + this.attemptId
                 + " at state " + oldState + ", error=" + e.getMessage()));
         eventHandler.handle(
             new DAGEvent(
-                this.attemptId.getTaskID().getVertexID().getDAGId(),
+                getDAGID(),
                 DAGEventType.INTERNAL_ERROR)
         );
       }
@@ -942,6 +946,8 @@ public class TaskAttemptImpl implements TaskAttempt,
     // set the finish time only if launch time is set
     if (launchTime != 0 && finishTime == 0) {
       finishTime = clock.getTime();
+      // The default clock is not safe for measuring durations.
+      finishTimeNs = System.nanoTime();
     }
   }
 
@@ -969,6 +975,10 @@ public class TaskAttemptImpl implements TaskAttempt,
       jce.addCounterUpdate(DAGCounter.NUM_SUCCEEDED_TASKS, 1);
     }
 
+    long amSideWallClockTimeMs = TimeUnit.NANOSECONDS.toMillis(
+        taskAttempt.getDurationNs());
+    jce.addCounterUpdate(DAGCounter.WALL_CLOCK_MILLIS, amSideWallClockTimeMs);
+
     return jce;
   }
 
@@ -1044,6 +1054,14 @@ public class TaskAttemptImpl implements TaskAttempt,
 //    */
 //  }
 
+  /**
+   * Records the launch time of the task.
+   */
+  private void setLaunchTime() {
+    launchTime = clock.getTime();
+    launchTimeNs = System.nanoTime();
+  }
+
   private void updateProgressSplits() {
 //    double newProgress = reportedStatus.progress;
 //    newProgress = Math.max(Math.min(newProgress, 1.0D), 0.0D);
@@ -1227,14 +1245,13 @@ public class TaskAttemptImpl implements TaskAttempt,
             ta.recoveryData.getTaskAttemptStartedEvent();
         if (taStartedEvent != null) {
           ta.launchTime = taStartedEvent.getStartTime();
+          ta.isRecoveredDuration = true;
           TaskAttemptFinishedEvent taFinishedEvent =
               ta.recoveryData.getTaskAttemptFinishedEvent();
           if (taFinishedEvent == null) {
-            if (LOG.isDebugEnabled()) {
-              LOG.debug("Only TaskAttemptStartedEvent but no TaskAttemptFinishedEvent, "
-                  + "send out TaskAttemptEventAttemptKilled to move it to KILLED");
-            }
-            ta.sendEvent(new TaskAttemptEventAttemptKilled(ta.getID(), 
+            LOG.debug("Only TaskAttemptStartedEvent but no TaskAttemptFinishedEvent, "
+                + "send out TaskAttemptEventAttemptKilled to move it to KILLED");
+            ta.sendEvent(new TaskAttemptEventAttemptKilled(ta.getTaskAttemptID(),
                 "Task Attempt killed in recovery due to can't recover the running task attempt",
                 TaskAttemptTerminationCause.TERMINATED_AT_RECOVERY, true));
             return TaskAttemptStateInternal.NEW;
@@ -1245,38 +1262,29 @@ public class TaskAttemptImpl implements TaskAttempt,
         TaskAttemptFinishedEvent taFinishedEvent =
             ta.recoveryData.getTaskAttemptFinishedEvent();
         Preconditions.checkArgument(taFinishedEvent != null, "Both of TaskAttemptStartedEvent and TaskFinishedEvent is null,"
-            + "taskAttemptId=" + ta.getID());
+            + "taskAttemptId=" + ta.getTaskAttemptID());
         switch (taFinishedEvent.getState()) {
           case FAILED:
-            if (LOG.isDebugEnabled()) {
-              LOG.debug("TaskAttemptFinishedEvent is seen with state of FAILED"
-                  + ", send TA_FAILED to itself"
-                  + ", attemptId=" + ta.attemptId);
-            }
-            ta.sendEvent(new TaskAttemptEventAttemptFailed(ta.getID(), TaskAttemptEventType.TA_FAILED,
+            LOG.debug("TaskAttemptFinishedEvent is seen with state of FAILED, "
+                + "send TA_FAILED to itself, attemptId={}", ta.attemptId);
+            ta.sendEvent(new TaskAttemptEventAttemptFailed(ta.getTaskAttemptID(), TaskAttemptEventType.TA_FAILED,
                 taFinishedEvent.getTaskFailureType(),
                 taFinishedEvent.getDiagnostics(), taFinishedEvent.getTaskAttemptError(), true));
             break;
           case KILLED:
-            if (LOG.isDebugEnabled()) {
-              LOG.debug("TaskAttemptFinishedEvent is seen with state of KILLED"
-                  + ", send TA_KILLED to itself"
-                  + ", attemptId=" + ta.attemptId);
-            }
-            ta.sendEvent(new TaskAttemptEventAttemptKilled(ta.getID(),
+            LOG.debug("TaskAttemptFinishedEvent is seen with state of KILLED, "
+                + "send TA_KILLED to itself, attemptId={}", ta.attemptId);
+            ta.sendEvent(new TaskAttemptEventAttemptKilled(ta.getTaskAttemptID(),
                 taFinishedEvent.getDiagnostics(), taFinishedEvent.getTaskAttemptError(), true));
             break;
           case SUCCEEDED:
-            if (LOG.isDebugEnabled()) {
-              LOG.debug("TaskAttemptFinishedEvent is seen with state of SUCCEEDED"
-                  + ", send TA_DONE to itself"
-                  + ", attemptId=" + ta.attemptId);
-            }
-            ta.sendEvent(new TaskAttemptEvent(ta.getID(), TaskAttemptEventType.TA_DONE));
+              LOG.debug("TaskAttemptFinishedEvent is seen with state of SUCCEEDED, "
+                  + "send TA_DONE to itself, attemptId={}", ta.attemptId);
+            ta.sendEvent(new TaskAttemptEvent(ta.getTaskAttemptID(), TaskAttemptEventType.TA_DONE));
             break;
           default:
             throw new TezUncheckedException("Invalid state in TaskAttemptFinishedEvent, state=" 
-                + taFinishedEvent.getState() + ", taId=" + ta.getID());
+                + taFinishedEvent.getState() + ", taId=" + ta.getTaskAttemptID());
         }
         return TaskAttemptStateInternal.NEW;
       }
@@ -1373,7 +1381,7 @@ public class TaskAttemptImpl implements TaskAttempt,
         ta.container = container;
         ta.containerId = tEvent.getContainerId();
         ta.containerNodeId = container.getNodeId();
-        ta.nodeHttpAddress = StringInterner.weakIntern(container.getNodeHttpAddress());
+        ta.nodeHttpAddress = StringInterner.intern(container.getNodeHttpAddress());
       }
 
       if (event instanceof TaskAttemptEventContainerTerminatedBySystem) {
@@ -1385,7 +1393,7 @@ public class TaskAttemptImpl implements TaskAttempt,
         ta.container = container;
         ta.containerId = tEvent.getContainerId();
         ta.containerNodeId = container.getNodeId();
-        ta.nodeHttpAddress = StringInterner.weakIntern(container.getNodeHttpAddress());
+        ta.nodeHttpAddress = StringInterner.intern(container.getNodeHttpAddress());
       }
 
       if (ta.recoveryData == null ||
@@ -1395,13 +1403,14 @@ public class TaskAttemptImpl implements TaskAttempt,
             .getTaskAttemptState(), helper.getFailureType(event));
       } else {
         ta.finishTime = ta.recoveryData.getTaskAttemptFinishedEvent().getFinishTime();
+        ta.isRecoveredDuration = true;
       }
 
       if (event instanceof RecoveryEvent) {
         RecoveryEvent rEvent = (RecoveryEvent)event;
         if (rEvent.isFromRecovery()) {
           if (LOG.isDebugEnabled()) {
-            LOG.debug("Faked TerminateEvent from recovery, taskAttemptId=" + ta.getID());
+            LOG.debug("Faked TerminateEvent from recovery, taskAttemptId=" + ta.getTaskAttemptID());
           }
         }
       }
@@ -1426,17 +1435,17 @@ public class TaskAttemptImpl implements TaskAttempt,
       ta.container = container;
       ta.containerId = event.getContainerId();
       ta.containerNodeId = container.getNodeId();
-      ta.nodeHttpAddress = StringInterner.weakIntern(container.getNodeHttpAddress());
-      ta.nodeRackName = StringInterner.weakIntern(RackResolver.resolve(ta.containerNodeId.getHost())
+      ta.nodeHttpAddress = StringInterner.intern(container.getNodeHttpAddress());
+      ta.nodeRackName = StringInterner.intern(RackResolver.resolve(ta.containerNodeId.getHost())
           .getNetworkLocation());
       ta.lastNotifyProgressTimestamp = ta.clock.getTime();
 
-      ta.launchTime = ta.clock.getTime();
+      ta.setLaunchTime();
 
       // TODO Resolve to host / IP in case of a local address.
       InetSocketAddress nodeHttpInetAddr = NetUtils
           .createSocketAddr(ta.nodeHttpAddress); // TODO: Costly?
-      ta.trackerName = StringInterner.weakIntern(nodeHttpInetAddr.getHostName());
+      ta.trackerName = StringInterner.intern(nodeHttpInetAddr.getHostName());
       ta.httpPort = nodeHttpInetAddr.getPort();
       ta.sendEvent(createDAGCounterUpdateEventTALaunched(ta));
 
@@ -1586,10 +1595,10 @@ public class TaskAttemptImpl implements TaskAttempt,
           // task is hung
           String diagnostics = "Attempt failed because it appears to make no progress for " + 
           ta.hungIntervalMax + "ms";
-          LOG.info(diagnostics + " " + ta.getID());
+          LOG.info(diagnostics + " " + ta.getTaskAttemptID());
           // send event that will fail this attempt
           ta.sendEvent(
-              new TaskAttemptEventAttemptFailed(ta.getID(),
+              new TaskAttemptEventAttemptFailed(ta.getTaskAttemptID(),
                   TaskAttemptEventType.TA_FAILED,
                   TaskFailureType.NON_FATAL,
                   diagnostics, 
@@ -1633,15 +1642,14 @@ public class TaskAttemptImpl implements TaskAttempt,
       if (ta.recoveryData != null && ta.recoveryData.isTaskAttemptSucceeded()) {
         TaskAttemptFinishedEvent taFinishedEvent = ta.recoveryData
             .getTaskAttemptFinishedEvent();
-        if (LOG.isDebugEnabled()) {
-          LOG.debug("TaskAttempt is recovered to SUCCEEDED, attemptId=" + ta.attemptId);
-        }
+        LOG.debug("TaskAttempt is recovered to SUCCEEDED, attemptId={}", ta.attemptId);
         ta.reportedStatus.counters = taFinishedEvent.getCounters();
         List<TezEvent> tezEvents = taFinishedEvent.getTAGeneratedEvents();
         if (tezEvents != null && !tezEvents.isEmpty()) {
           ta.sendEvent(new VertexEventRouteEvent(ta.getVertexID(), tezEvents));
         }
         ta.finishTime = taFinishedEvent.getFinishTime();
+        ta.isRecoveredDuration = true;
       } else {
         ta.setFinishTime();
         // Send out history event.
@@ -1767,80 +1775,130 @@ public class TaskAttemptImpl implements TaskAttempt,
   MultipleArcTransition<TaskAttemptImpl, TaskAttemptEvent, TaskAttemptStateInternal> {
 
     @Override
-    public TaskAttemptStateInternal transition(TaskAttemptImpl attempt,
+    public TaskAttemptStateInternal transition(TaskAttemptImpl sourceAttempt,
         TaskAttemptEvent event) {
       TaskAttemptEventOutputFailed outputFailedEvent = 
           (TaskAttemptEventOutputFailed) event;
-      TezEvent tezEvent = outputFailedEvent.getInputFailedEvent();
-      TezTaskAttemptID failedDestTaId = tezEvent.getSourceInfo().getTaskAttemptID();
-      InputReadErrorEvent readErrorEvent = (InputReadErrorEvent)tezEvent.getEvent();
+      TezEvent inputFailedEvent = outputFailedEvent.getInputFailedEvent();
+      TezTaskAttemptID failedDestTaId = inputFailedEvent.getSourceInfo().getTaskAttemptID();
+
+      InputReadErrorEvent readErrorEvent = (InputReadErrorEvent)inputFailedEvent.getEvent();
       int failedInputIndexOnDestTa = readErrorEvent.getIndex();
-      if (readErrorEvent.getVersion() != attempt.getID().getId()) {
-        throw new TezUncheckedException(attempt.getID()
+
+      if (readErrorEvent.getVersion() != sourceAttempt.getTaskAttemptID().getId()) {
+        throw new TezUncheckedException(sourceAttempt.getTaskAttemptID()
             + " incorrectly blamed for read error from " + failedDestTaId
             + " at inputIndex " + failedInputIndexOnDestTa + " version"
             + readErrorEvent.getVersion());
       }
-      LOG.info(attempt.getID()
-            + " blamed for read error from " + failedDestTaId
-            + " at inputIndex " + failedInputIndexOnDestTa);
-      long time = attempt.clock.getTime();
-      Long firstErrReportTime = attempt.uniquefailedOutputReports.get(failedDestTaId);
+      // source host: where the data input is supposed to come from
+      String sHost = sourceAttempt.getNodeId().getHost();
+      // destination: where the data is tried to be fetched to
+      String dHost = readErrorEvent.getDestinationLocalhostName();
+
+      LOG.info("{} (on {}) blamed for read error from {} (on {}) at inputIndex {}", sourceAttempt.getTaskAttemptID(),
+          sHost, failedDestTaId, dHost, failedInputIndexOnDestTa);
+
+      boolean tooManyDownstreamHostsBlamedTheSameUpstreamHost = false;
+      Map<String, Set<String>> downstreamBlamingHosts = sourceAttempt.getVertex().getDownstreamBlamingHosts();
+      if (!downstreamBlamingHosts.containsKey(sHost)) {
+        LOG.info("Host {} is blamed for fetch failure from {} for the first time", sHost, dHost);
+        downstreamBlamingHosts.put(sHost, new HashSet<String>());
+      }
+
+      downstreamBlamingHosts.get(sHost).add(dHost);
+      int currentNumberOfFailingDownstreamHosts = downstreamBlamingHosts.get(sHost).size();
+      int numNodes = getNumNodes(sourceAttempt);
+      float hostFailureFraction = numNodes > 0 ? ((float) currentNumberOfFailingDownstreamHosts) / numNodes : 0;
+      double maxAllowedHostFailureFraction = sourceAttempt.getVertex().getVertexConfig()
+          .getMaxAllowedDownstreamHostFailuresFraction();
+
+      if (hostFailureFraction > maxAllowedHostFailureFraction) {
+        LOG.info("Host will be marked fail: {} because of host failure fraction {} is beyond the limit {}", sHost,
+            hostFailureFraction, maxAllowedHostFailureFraction);
+        tooManyDownstreamHostsBlamedTheSameUpstreamHost = true;
+      }
+
+      long time = sourceAttempt.clock.getTime();
+
+      Long firstErrReportTime = sourceAttempt.uniquefailedOutputReports.get(failedDestTaId);
       if (firstErrReportTime == null) {
-        attempt.uniquefailedOutputReports.put(failedDestTaId, time);
+        sourceAttempt.uniquefailedOutputReports.put(failedDestTaId, time);
         firstErrReportTime = time;
       }
 
-      int maxAllowedOutputFailures = attempt.getVertex().getVertexConfig()
+      int maxAllowedOutputFailures = sourceAttempt.getVertex().getVertexConfig()
           .getMaxAllowedOutputFailures();
-      int maxAllowedTimeForTaskReadErrorSec = attempt.getVertex()
+      int maxAllowedTimeForTaskReadErrorSec = sourceAttempt.getVertex()
           .getVertexConfig().getMaxAllowedTimeForTaskReadErrorSec();
-      double maxAllowedOutputFailuresFraction = attempt.getVertex()
+      double maxAllowedOutputFailuresFraction = sourceAttempt.getVertex()
           .getVertexConfig().getMaxAllowedOutputFailuresFraction();
 
       int readErrorTimespanSec = (int)((time - firstErrReportTime)/1000);
       boolean crossTimeDeadline = readErrorTimespanSec >= maxAllowedTimeForTaskReadErrorSec;
 
-      int runningTasks = attempt.appContext.getCurrentDAG().getVertex(
-          failedDestTaId.getTaskID().getVertexID()).getRunningTasks();
-      float failureFraction = runningTasks > 0 ? ((float) attempt.uniquefailedOutputReports.size()) / runningTasks : 0;
+      int runningTasks = sourceAttempt.appContext.getCurrentDAG().getVertex(
+          failedDestTaId.getVertexID()).getRunningTasks();
+      float failureFraction =
+          runningTasks > 0 ? ((float) sourceAttempt.uniquefailedOutputReports.size()) / runningTasks : 0;
       boolean withinFailureFractionLimits =
           (failureFraction <= maxAllowedOutputFailuresFraction);
       boolean withinOutputFailureLimits =
-          (attempt.uniquefailedOutputReports.size() < maxAllowedOutputFailures);
+          (sourceAttempt.uniquefailedOutputReports.size() < maxAllowedOutputFailures);
 
       // If needed we can launch a background task without failing this task
       // to generate a copy of the output just in case.
       // If needed we can consider only running consumer tasks
-      if (!crossTimeDeadline && withinFailureFractionLimits && withinOutputFailureLimits) {
-        return attempt.getInternalState();
+      if (!crossTimeDeadline && withinFailureFractionLimits && withinOutputFailureLimits
+          && !(readErrorEvent.isLocalFetch() || readErrorEvent.isDiskErrorAtSource())
+          && !tooManyDownstreamHostsBlamedTheSameUpstreamHost) {
+        return sourceAttempt.getInternalState();
       }
-      String message = attempt.getID() + " being failed for too many output errors. "
+      String message = sourceAttempt.getTaskAttemptID() + " being failed for too many output errors. "
           + "failureFraction=" + failureFraction
           + ", MAX_ALLOWED_OUTPUT_FAILURES_FRACTION="
           + maxAllowedOutputFailuresFraction
-          + ", uniquefailedOutputReports=" + attempt.uniquefailedOutputReports.size()
+          + ", uniquefailedOutputReports=" + sourceAttempt.uniquefailedOutputReports.size()
           + ", MAX_ALLOWED_OUTPUT_FAILURES=" + maxAllowedOutputFailures
+          + ", hostFailureFraction=" + hostFailureFraction
+          + " (" + currentNumberOfFailingDownstreamHosts + " / " + numNodes + ")"
+          + ", MAX_ALLOWED_DOWNSTREAM_HOST_FAILURES_FRACTION="
+          + maxAllowedHostFailureFraction
           + ", MAX_ALLOWED_TIME_FOR_TASK_READ_ERROR_SEC="
           + maxAllowedTimeForTaskReadErrorSec
-          + ", readErrorTimespan=" + readErrorTimespanSec;
+          + ", readErrorTimespan=" + readErrorTimespanSec
+          + ", isLocalFetch=" + readErrorEvent.isLocalFetch()
+          + ", isDiskErrorAtSource=" + readErrorEvent.isDiskErrorAtSource();
+
       LOG.info(message);
-      attempt.addDiagnosticInfo(message);
+      sourceAttempt.addDiagnosticInfo(message);
       // send input failed event
-      attempt.sendInputFailedToConsumers();
+      sourceAttempt.sendInputFailedToConsumers();
       // Not checking for leafVertex since a READ_ERROR should only be reported for intermediate tasks.
-      if (attempt.getInternalState() == TaskAttemptStateInternal.SUCCEEDED) {
+      if (sourceAttempt.getInternalState() == TaskAttemptStateInternal.SUCCEEDED) {
         (new TerminatedAfterSuccessHelper(FAILED_HELPER)).transition(
-            attempt, event);
+            sourceAttempt, event);
         return TaskAttemptStateInternal.FAILED;
       } else {
         (new TerminatedWhileRunningTransition(FAILED_HELPER)).transition(
-            attempt, event);
+            sourceAttempt, event);
         return TaskAttemptStateInternal.FAIL_IN_PROGRESS;
       }
       // TODO at some point. Nodes may be interested in FetchFailure info.
       // Can be used to blacklist nodes.
     }
+
+    private int getNumNodes(TaskAttemptImpl sourceAttempt) {
+      Vertex vertex = sourceAttempt.getVertex();
+      String taskSchedulerName = vertex.getServicePluginInfo().getTaskSchedulerName();
+      int sourceIndex = vertex.getAppContext().getTaskScheduerIdentifier(taskSchedulerName);
+      int numActiveNodes = vertex.getAppContext().getNodeTracker().getNumActiveNodes(sourceIndex);
+      if (LOG.isDebugEnabled()) {
+        int numAllNodes = vertex.getAppContext().getNodeTracker().getNumNodes(sourceIndex);
+        LOG.debug("Getting nodes, active/all: {}/{}", numActiveNodes, numAllNodes);
+      }
+      return numActiveNodes;
+    }
   }
   
   @VisibleForTesting
@@ -1853,8 +1911,8 @@ public class TaskAttemptImpl implements TaskAttempt,
         tezIfEvents.add(new TezEvent(new InputFailedEvent(), 
             new EventMetaData(EventProducerConsumerType.SYSTEM, 
                 vertex.getName(), 
-                edgeVertex.getName(), 
-                getID()), appContext.getClock().getTime()));
+                edgeVertex.getName(),
+                    getTaskAttemptID()), appContext.getClock().getTime()));
       }
       sendEvent(new VertexEventRouteEvent(vertex.getVertexId(), tezIfEvents));
     }
@@ -1948,7 +2006,7 @@ public class TaskAttemptImpl implements TaskAttempt,
 
   @Override
   public String toString() {
-    return getID().toString();
+    return getTaskAttemptID().toString();
   }
 
 
