@@ -32,6 +32,7 @@ import java.util.Map.Entry;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.PriorityBlockingQueue;
+import java.util.concurrent.ThreadLocalRandom;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
 
@@ -44,7 +45,6 @@ import org.apache.tez.serviceplugins.api.TaskSchedulerContext.AppFinalStatus;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.apache.commons.lang.exception.ExceptionUtils;
-import org.apache.commons.math3.random.RandomDataGenerator;
 import org.apache.hadoop.classification.InterfaceAudience.Private;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.util.ExitUtil;
@@ -69,7 +69,7 @@ import org.apache.tez.dag.api.TezUncheckedException;
 import org.apache.tez.common.ContainerSignatureMatcher;
 
 import com.google.common.annotations.VisibleForTesting;
-import com.google.common.base.Preconditions;
+import org.apache.tez.common.Preconditions;
 import com.google.common.collect.Lists;
 import com.google.common.collect.Maps;
 import com.google.common.collect.Sets;
@@ -153,7 +153,6 @@ public class YarnTaskSchedulerService extends TaskScheduler
   
   Set<ContainerId> sessionMinHeldContainers = Sets.newHashSet();
   
-  RandomDataGenerator random = new RandomDataGenerator();
   private final Configuration conf;
 
   @VisibleForTesting
@@ -449,10 +448,8 @@ public class YarnTaskSchedulerService extends TaskScheduler
           // being released
           // completion of a container we had released earlier
           // an allocated container completed. notify app
-          if (LOG.isDebugEnabled()) {
-            LOG.debug("Released container completed:" + completedId +
-                " last allocated to task: " + task);
-          }
+          LOG.debug("Released container completed:{} last allocated to task: {}",
+            completedId, task);
           appContainerStatus.put(task, containerStatus);
           continue;
         }
@@ -595,7 +592,7 @@ public class YarnTaskSchedulerService extends TaskScheduler
     long expireTime = (startTime + idleContainerTimeoutMin);
     if (idleContainerTimeoutMin != -1 && idleContainerTimeoutMin < idleContainerTimeoutMax) {
       long expireTimeMax = startTime + idleContainerTimeoutMax;
-      expireTime = random.nextLong(expireTime, expireTimeMax);
+      expireTime = ThreadLocalRandom.current().nextLong(expireTime, expireTimeMax);
     }
     
     return expireTime;
@@ -1216,12 +1213,9 @@ public class YarnTaskSchedulerService extends TaskScheduler
 
       if(!preemptionWaitDeadlineCrossed && 
           fitsIn(highestPriRequest.getCapability(), freeResources)) {
-        if (LOG.isDebugEnabled()) {
-          LOG.debug(highestPriRequest + " fits in free resources");
-        } else {
-          if (numHeartbeats % 50 == 1) {
-            LOG.info(highestPriRequest + " fits in free resources");
-          }
+        LOG.debug("{} fits in free resources", highestPriRequest);
+        if (numHeartbeats % 50 == 1) {
+          LOG.info(highestPriRequest + " fits in free resources");
         }
         return true;
       }
@@ -1509,10 +1503,8 @@ public class YarnTaskSchedulerService extends TaskScheduler
               if (container.getId().equals(
                   cookieContainerRequest.getAffinitizedContainer())) {
                 // container level match
-                if (LOG.isDebugEnabled()) {
-                  LOG.debug("Matching with affinity for request: "
-                      + cookieContainerRequest + " container: " + affCId);
-                }
+                  LOG.debug("Matching with affinity for request: {} container: {}",
+                    cookieContainerRequest, affCId);
                 return cookieContainerRequest;
               }
               if (LOG.isDebugEnabled()) {
@@ -1536,7 +1528,8 @@ public class YarnTaskSchedulerService extends TaskScheduler
     HeldContainer heldContainer = heldContainers.get(container.getId());
     Object task = getTask(cookieContainerRequest);
     if (task instanceof TaskAttempt
-        && ((TaskAttempt) task).getNodesWithSiblingRunningAttempts().contains(container.getNodeId())) {
+        && ((TaskAttempt) task).getTask() != null
+        && ((TaskAttempt) task).getTask().getNodesWithRunningAttempts().contains(container.getNodeId())) {
       return false;
     }
     if (heldContainer == null || heldContainer.isNew()) { // New container.
@@ -1790,9 +1783,9 @@ public class YarnTaskSchedulerService extends TaskScheduler
       Container container = entry.getValue();
       // check for blacklisted nodes. There may be race conditions between
       // setting blacklist and receiving allocations
-      CookieContainerRequest request = entry.getKey();
-      Object task = getTask(request);
       if (blacklistedNodes.contains(container.getNodeId())) {
+        CookieContainerRequest request = entry.getKey();
+        Object task = getTask(request);
         LOG.info("Container: " + container.getId() + 
             " allocated on blacklisted node: " + container.getNodeId() + 
             " for task: " + task);
@@ -2024,10 +2017,7 @@ public class YarnTaskSchedulerService extends TaskScheduler
         if (delayedContainer == null) {
           continue;
         }
-        if (LOG.isDebugEnabled()) {
-          LOG.debug("Considering HeldContainer: "
-              + delayedContainer + " for assignment");
-        }
+        LOG.debug("Considering HeldContainer: {} for assignment", delayedContainer);
         long currentTs = System.currentTimeMillis();
         long nextScheduleTs = delayedContainer.getNextScheduleTime();
         if (currentTs >= nextScheduleTs) {
@@ -2090,10 +2080,7 @@ public class YarnTaskSchedulerService extends TaskScheduler
         // honor reuse-locality flags (container not timed out yet), Don't queue
         // (already in queue), don't release (release happens when containers
         // time-out)
-        if (LOG.isDebugEnabled()) {
-          LOG.debug("Trying to assign all delayed containers to newly received"
-            + " tasks");
-        }
+        LOG.debug("Trying to assign all delayed containers to newly received tasks");
         Iterator<HeldContainer> iter = delayedContainers.iterator();
         while(iter.hasNext()) {
           HeldContainer delayedContainer = iter.next();
