@@ -43,8 +43,8 @@ import java.util.concurrent.TimeUnit;
 import java.util.concurrent.TimeoutException;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
+import java.util.Objects;
 
-import com.google.common.base.Preconditions;
 import com.google.common.collect.Lists;
 import com.google.common.collect.Maps;
 import org.apache.hadoop.conf.Configuration;
@@ -392,8 +392,8 @@ class TestTaskSchedulerHelpers {
 
     @Override
     public boolean isSuperSet(Object cs1, Object cs2) {
-      Preconditions.checkNotNull(cs1, "Arguments cannot be null");
-      Preconditions.checkNotNull(cs2, "Arguments cannot be null");
+      Objects.requireNonNull(cs1, "Arguments cannot be null");
+      Objects.requireNonNull(cs2, "Arguments cannot be null");
       return true;
     }
 
@@ -417,8 +417,8 @@ class TestTaskSchedulerHelpers {
   static class PreemptionMatcher implements ContainerSignatureMatcher {
     @Override
     public boolean isSuperSet(Object cs1, Object cs2) {
-      Preconditions.checkNotNull(cs1, "Arguments cannot be null");
-      Preconditions.checkNotNull(cs2, "Arguments cannot be null");
+      Objects.requireNonNull(cs1, "Arguments cannot be null");
+      Objects.requireNonNull(cs2, "Arguments cannot be null");
       return true;
     }
 
