@@ -148,7 +148,7 @@ public class YARNRunner implements ClientProtocol {
    * @param conf the configuration object for the client
    */
   public YARNRunner(Configuration conf) {
-   this(conf, new ResourceMgrDelegate(new YarnConfiguration(conf)));
+    this(conf, new ResourceMgrDelegate(new YarnConfiguration(conf)));
   }
 
   /**
@@ -616,9 +616,7 @@ public class YARNRunner implements ClientProtocol {
     dagAMConf.set(TezConfiguration.TEZ_AM_LAUNCH_CMD_OPTS, javaOpts.toString());
     if (envStr.length() > 0) {
       dagAMConf.set(TezConfiguration.TEZ_AM_LAUNCH_ENV, envStr);
-      if (LOG.isDebugEnabled()) {
-        LOG.debug("Setting MR AM env to : " + envStr);
-      }
+      LOG.debug("Setting MR AM env to : {}", envStr);
     }
 
     // Submit to ResourceManager
