@@ -47,6 +47,7 @@ import org.apache.tez.mapreduce.hadoop.MRInputHelpers;
 import org.apache.tez.mapreduce.protos.MRRuntimeProtos;
 import org.apache.tez.runtime.api.Event;
 import org.apache.tez.runtime.api.InputContext;
+import org.apache.tez.runtime.api.InputStatisticsReporter;
 import org.apache.tez.runtime.api.events.InputDataInformationEvent;
 import org.junit.Test;
 
@@ -69,6 +70,7 @@ public class TestMRInput {
     doReturn(1).when(inputContext).getTaskIndex();
     doReturn(1).when(inputContext).getTaskAttemptNumber();
     doReturn(new TezCounters()).when(inputContext).getCounters();
+    doReturn(new JobConf(false)).when(inputContext).getContainerConfiguration();
 
 
     MRInput mrInput = new MRInput(inputContext, 0);
@@ -120,6 +122,7 @@ public class TestMRInput {
     doReturn(TEST_ATTRIBUTES_INPUT_NAME).when(inputContext).getSourceVertexName();
     doReturn(TEST_ATTRIBUTES_APPLICATION_ID).when(inputContext).getApplicationId();
     doReturn(TEST_ATTRIBUTES_UNIQUE_IDENTIFIER).when(inputContext).getUniqueIdentifier();
+    doReturn(new Configuration(false)).when(inputContext).getContainerConfiguration();
 
 
     DataSourceDescriptor dsd = MRInput.createConfigBuilder(new Configuration(false),
@@ -147,6 +150,53 @@ public class TestMRInput {
     assertTrue(TestInputFormat.invoked.get());
   }
 
+  @Test(timeout = 5000)
+  public void testConfigMerge() throws Exception {
+    JobConf jobConf = new JobConf(false);
+    jobConf.set("payload-key", "payload-value");
+
+    Configuration localConfig = new Configuration(false);
+    localConfig.set("local-key", "local-value");
+
+    InputContext inputContext = mock(InputContext.class);
+
+    DataSourceDescriptor dsd = MRInput.createConfigBuilder(jobConf,
+        TestInputFormat.class).groupSplits(false).build();
+
+    doReturn(dsd.getInputDescriptor().getUserPayload()).when(inputContext).getUserPayload();
+    doReturn(TEST_ATTRIBUTES_DAG_INDEX).when(inputContext).getDagIdentifier();
+    doReturn(TEST_ATTRIBUTES_VERTEX_INDEX).when(inputContext).getTaskVertexIndex();
+    doReturn(TEST_ATTRIBUTES_TASK_INDEX).when(inputContext).getTaskIndex();
+    doReturn(TEST_ATTRIBUTES_TASK_ATTEMPT_INDEX).when(inputContext).getTaskAttemptNumber();
+    doReturn(TEST_ATTRIBUTES_INPUT_INDEX).when(inputContext).getInputIndex();
+    doReturn(TEST_ATTRIBUTES_DAG_ATTEMPT_NUMBER).when(inputContext).getDAGAttemptNumber();
+    doReturn(TEST_ATTRIBUTES_DAG_NAME).when(inputContext).getDAGName();
+    doReturn(TEST_ATTRIBUTES_VERTEX_NAME).when(inputContext).getTaskVertexName();
+    doReturn(TEST_ATTRIBUTES_INPUT_NAME).when(inputContext).getSourceVertexName();
+    doReturn(TEST_ATTRIBUTES_APPLICATION_ID).when(inputContext).getApplicationId();
+    doReturn(TEST_ATTRIBUTES_UNIQUE_IDENTIFIER).when(inputContext).getUniqueIdentifier();
+    doReturn(localConfig).when(inputContext).getContainerConfiguration();
+    doReturn(new TezCounters()).when(inputContext).getCounters();
+
+    MRInputForTest input = new MRInputForTest(inputContext, 1);
+    input.initialize();
+
+    Configuration mergedConfig = input.getConfiguration();
+
+    assertEquals("local-value", mergedConfig.get("local-key"));
+    assertEquals("payload-value", mergedConfig.get("payload-key"));
+  }
+
+  @Test
+  public void testMRInputCloseWithUnintializedReader() throws IOException {
+    InputContext inputContext = mock(InputContext.class);
+    doReturn(new TezCounters()).when(inputContext).getCounters();
+    doReturn(new InputStatisticsReporterImplForTest()).when(inputContext).getStatisticsReporter();
+
+    MRInput mrInput = new MRInput(inputContext, 0);
+    mrInput.close(); // shouldn't throw NPE
+  }
+
   /**
    * Test class to verify
    */
@@ -237,4 +287,15 @@ public class TestMRInput {
 
     }
   }
+
+  public static class InputStatisticsReporterImplForTest implements InputStatisticsReporter {
+
+    @Override
+    public synchronized void reportDataSize(long size) {
+    }
+
+    @Override
+    public void reportItemsProcessed(long items) {
+    }
+  }
 }
