@@ -28,6 +28,7 @@ import java.io.Writer;
 import java.util.HashMap;
 import java.util.List;
 
+import com.google.common.io.Files;
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
@@ -66,6 +67,7 @@ import org.apache.tez.runtime.api.impl.TaskSpec;
 import org.apache.tez.runtime.api.impl.TezUmbilical;
 import org.apache.tez.runtime.library.api.KeyValueWriter;
 import org.apache.tez.runtime.library.processor.SimpleProcessor;
+import org.junit.BeforeClass;
 import org.junit.Ignore;
 import org.junit.Test;
 
@@ -75,16 +77,25 @@ import com.google.common.collect.Lists;
 
 public class TestMROutput {
 
+  static File tmpDir;
+
+  @BeforeClass
+  public static void setupClass () {
+    tmpDir = Files.createTempDir();
+    tmpDir.deleteOnExit();
+  }
+
   @Test(timeout = 5000)
   public void testNewAPI_TextOutputFormat() throws Exception {
-    String outputPath = "/tmp/output";
     Configuration conf = new Configuration();
     conf.setBoolean(MRConfig.IS_MAP_PROCESSOR, true);
     DataSinkDescriptor dataSink = MROutput
-        .createConfigBuilder(conf, TextOutputFormat.class, outputPath)
+        .createConfigBuilder(conf, TextOutputFormat.class,
+            tmpDir.getPath())
         .build();
 
-    OutputContext outputContext = createMockOutputContext(dataSink.getOutputDescriptor().getUserPayload());
+    OutputContext outputContext = createMockOutputContext(dataSink.getOutputDescriptor().getUserPayload(),
+        new Configuration(false));
     MROutput output = new MROutput(outputContext, 2);
     output.initialize();
 
@@ -99,16 +110,39 @@ public class TestMROutput {
     assertEquals(FileOutputCommitter.class, output.committer.getClass());
   }
 
+  @Test
+  public void testMergeConfig() throws Exception {
+    String outputPath = "/tmp/output";
+    Configuration localConf = new Configuration(false);
+    localConf.set("local-key", "local-value");
+    DataSinkDescriptor dataSink = MROutput
+        .createConfigBuilder(localConf, org.apache.hadoop.mapred.TextOutputFormat.class, outputPath)
+        .build();
+
+    Configuration baseConf = new Configuration(false);
+    baseConf.set("base-key", "base-value");
+
+    OutputContext outputContext = createMockOutputContext(dataSink.getOutputDescriptor().getUserPayload(), baseConf);
+    MROutput output = new MROutput(outputContext, 2);
+    output.initialize();
+
+    Configuration mergedConf = output.jobConf;
+    assertEquals("local-value", mergedConf.get("local-key"));
+    assertEquals("base-value", mergedConf.get("base-key"));
+  }
+
   @Test(timeout = 5000)
   public void testOldAPI_TextOutputFormat() throws Exception {
-    String outputPath = "/tmp/output";
     Configuration conf = new Configuration();
     conf.setBoolean(MRConfig.IS_MAP_PROCESSOR, false);
     DataSinkDescriptor dataSink = MROutput
-        .createConfigBuilder(conf, org.apache.hadoop.mapred.TextOutputFormat.class, outputPath)
+        .createConfigBuilder(conf,
+            org.apache.hadoop.mapred.TextOutputFormat.class,
+            tmpDir.getPath())
         .build();
 
-    OutputContext outputContext = createMockOutputContext(dataSink.getOutputDescriptor().getUserPayload());
+    OutputContext outputContext = createMockOutputContext(dataSink.getOutputDescriptor().getUserPayload(),
+        new Configuration(false));
     MROutput output = new MROutput(outputContext, 2);
     output.initialize();
 
@@ -125,15 +159,16 @@ public class TestMROutput {
 
   @Test(timeout = 5000)
   public void testNewAPI_SequenceFileOutputFormat() throws Exception {
-    String outputPath = "/tmp/output";
     JobConf conf = new JobConf();
     conf.setOutputKeyClass(NullWritable.class);
     conf.setOutputValueClass(Text.class);
     DataSinkDescriptor dataSink = MROutput
-        .createConfigBuilder(conf, SequenceFileOutputFormat.class, outputPath)
+        .createConfigBuilder(conf, SequenceFileOutputFormat.class,
+            tmpDir.getPath())
         .build();
 
-    OutputContext outputContext = createMockOutputContext(dataSink.getOutputDescriptor().getUserPayload());
+    OutputContext outputContext = createMockOutputContext(dataSink.getOutputDescriptor().getUserPayload(),
+        new Configuration(false));
     MROutput output = new MROutput(outputContext, 2);
     output.initialize();
     assertEquals(true, output.useNewApi);
@@ -149,15 +184,17 @@ public class TestMROutput {
 
   @Test(timeout = 5000)
   public void testOldAPI_SequenceFileOutputFormat() throws Exception {
-    String outputPath = "/tmp/output";
     JobConf conf = new JobConf();
     conf.setOutputKeyClass(NullWritable.class);
     conf.setOutputValueClass(Text.class);
     DataSinkDescriptor dataSink = MROutput
-        .createConfigBuilder(conf, org.apache.hadoop.mapred.SequenceFileOutputFormat.class, outputPath)
+        .createConfigBuilder(conf,
+            org.apache.hadoop.mapred.SequenceFileOutputFormat.class,
+            tmpDir.getPath())
         .build();
 
-    OutputContext outputContext = createMockOutputContext(dataSink.getOutputDescriptor().getUserPayload());
+    OutputContext outputContext = createMockOutputContext(dataSink.getOutputDescriptor().getUserPayload(),
+        new Configuration(false));
     MROutput output = new MROutput(outputContext, 2);
     output.initialize();
     assertEquals(false, output.useNewApi);
@@ -175,14 +212,15 @@ public class TestMROutput {
   // set while creating recordWriters
   @Test(timeout = 5000)
   public void testNewAPI_WorkOutputPathOutputFormat() throws Exception {
-    String outputPath = "/tmp/output";
     Configuration conf = new Configuration();
     conf.setBoolean(MRConfig.IS_MAP_PROCESSOR, true);
     DataSinkDescriptor dataSink = MROutput
-      .createConfigBuilder(conf, NewAPI_WorkOutputPathReadingOutputFormat.class, outputPath)
+      .createConfigBuilder(conf, NewAPI_WorkOutputPathReadingOutputFormat.class,
+          tmpDir.getPath())
       .build();
 
-    OutputContext outputContext = createMockOutputContext(dataSink.getOutputDescriptor().getUserPayload());
+    OutputContext outputContext = createMockOutputContext(dataSink.getOutputDescriptor().getUserPayload(),
+        new Configuration(false));
     MROutput output = new MROutput(outputContext, 2);
     output.initialize();
 
@@ -201,14 +239,15 @@ public class TestMROutput {
   // set while creating recordWriters
   @Test(timeout = 5000)
   public void testOldAPI_WorkOutputPathOutputFormat() throws Exception {
-    String outputPath = "/tmp/output";
     Configuration conf = new Configuration();
     conf.setBoolean(MRConfig.IS_MAP_PROCESSOR, false);
     DataSinkDescriptor dataSink = MROutput
-      .createConfigBuilder(conf, OldAPI_WorkOutputPathReadingOutputFormat.class, outputPath)
+      .createConfigBuilder(conf, OldAPI_WorkOutputPathReadingOutputFormat.class,
+          tmpDir.getPath())
       .build();
 
-    OutputContext outputContext = createMockOutputContext(dataSink.getOutputDescriptor().getUserPayload());
+    OutputContext outputContext = createMockOutputContext(dataSink.getOutputDescriptor().getUserPayload(),
+        new Configuration(false));
     MROutput output = new MROutput(outputContext, 2);
     output.initialize();
 
@@ -223,7 +262,7 @@ public class TestMROutput {
     assertEquals(org.apache.hadoop.mapred.FileOutputCommitter.class, output.committer.getClass());
   }
 
-  private OutputContext createMockOutputContext(UserPayload payload) {
+  private OutputContext createMockOutputContext(UserPayload payload, Configuration baseConf) {
     OutputContext outputContext = mock(OutputContext.class);
     ApplicationId appId = ApplicationId.newInstance(System.currentTimeMillis(), 1);
     when(outputContext.getUserPayload()).thenReturn(payload);
@@ -231,6 +270,7 @@ public class TestMROutput {
     when(outputContext.getTaskVertexIndex()).thenReturn(1);
     when(outputContext.getTaskAttemptNumber()).thenReturn(1);
     when(outputContext.getCounters()).thenReturn(new TezCounters());
+    when(outputContext.getContainerConfiguration()).thenReturn(baseConf);
     return outputContext;
   }
   
