@@ -18,6 +18,7 @@
 
 package org.apache.tez.auxservices;
 
+import org.apache.hadoop.fs.RemoteIterator;
 import org.apache.hadoop.util.DiskChecker;
 import static org.fusesource.leveldbjni.JniDBFactory.asString;
 import static org.fusesource.leveldbjni.JniDBFactory.bytes;
@@ -57,6 +58,8 @@ import javax.crypto.SecretKey;
 
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileContext;
+import org.apache.hadoop.fs.FileSystem;
+import org.apache.hadoop.fs.FileStatus;
 import org.apache.hadoop.fs.LocalDirAllocator;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.io.DataInputByteBuffer;
@@ -153,7 +156,6 @@ import com.google.common.cache.LoadingCache;
 import com.google.common.cache.RemovalListener;
 import com.google.common.cache.RemovalNotification;
 import com.google.common.cache.Weigher;
-import com.google.protobuf.ByteString;
 
 public class ShuffleHandler extends AuxiliaryService {
 
@@ -465,6 +467,10 @@ public class ShuffleHandler extends AuxiliaryService {
     return jt;
   }
 
+  public int getPort() {
+    return port;
+  }
+
   @Override
   public void initializeApplication(ApplicationInitializationContext context) {
 
@@ -538,7 +544,7 @@ public class ShuffleHandler extends AuxiliaryService {
         return new Thread(r, WORKER_THREAD_NAME_PREFIX + workerThreadCounter.incrementAndGet());
       }
     });
-
+    port = conf.getInt(SHUFFLE_PORT_CONFIG_KEY, DEFAULT_SHUFFLE_PORT);
     super.serviceInit(new YarnConfiguration(conf));
   }
 
@@ -557,7 +563,6 @@ public class ShuffleHandler extends AuxiliaryService {
             conf.getInt(SHUFFLE_LISTEN_QUEUE_SIZE, DEFAULT_SHUFFLE_LISTEN_QUEUE_SIZE))
         .childOption(ChannelOption.SO_KEEPALIVE, true);
     initPipeline(bootstrap, conf);
-    port = conf.getInt(SHUFFLE_PORT_CONFIG_KEY, DEFAULT_SHUFFLE_PORT);
     Channel ch = bootstrap.bind().sync().channel();
     accepted.add(ch);
 
@@ -796,9 +801,10 @@ public class ShuffleHandler extends AuxiliaryService {
   private void recordJobShuffleInfo(JobID jobId, String user,
       Token<JobTokenIdentifier> jobToken) throws IOException {
     if (stateDb != null) {
+      // Discover type instead of assuming ByteString to allow for shading.
       TokenProto tokenProto = TokenProto.newBuilder()
-          .setIdentifier(ByteString.copyFrom(jobToken.getIdentifier()))
-          .setPassword(ByteString.copyFrom(jobToken.getPassword()))
+          .setIdentifier(TokenProto.getDefaultInstance().getIdentifier().copyFrom(jobToken.getIdentifier()))
+          .setPassword(TokenProto.getDefaultInstance().getPassword().copyFrom(jobToken.getPassword()))
           .setKind(jobToken.getKind().toString())
           .setService(jobToken.getService().toString())
           .build();
@@ -1004,6 +1010,8 @@ public class ShuffleHandler extends AuxiliaryService {
       final Map<String, List<String>> q = new QueryStringDecoder(request.getUri()).parameters();
       final List<String> keepAliveList = q.get("keepAlive");
       final List<String> dagCompletedQ = q.get("dagAction");
+      final List<String> vertexCompletedQ = q.get("vertexAction");
+      final List<String> taskAttemptFailedQ = q.get("taskAttemptAction");
       boolean keepAliveParam = false;
       if (keepAliveList != null && keepAliveList.size() == 1) {
         keepAliveParam = Boolean.parseBoolean(keepAliveList.get(0));
@@ -1013,6 +1021,7 @@ public class ShuffleHandler extends AuxiliaryService {
       final Range reduceRange = splitReduces(q.get("reduce"));
       final List<String> jobQ = q.get("job");
       final List<String> dagIdQ = q.get("dag");
+      final List<String> vertexIdQ = q.get("vertex");
       if (LOG.isDebugEnabled()) {
         LOG.debug("RECV: " + request.getUri() +
             "\n  mapId: " + mapIds +
@@ -1025,6 +1034,12 @@ public class ShuffleHandler extends AuxiliaryService {
       if (deleteDagDirectories(ctx.channel(), dagCompletedQ, jobQ, dagIdQ))  {
         return;
       }
+      if (deleteVertexDirectories(ctx.channel(), vertexCompletedQ, jobQ, dagIdQ, vertexIdQ)) {
+        return;
+      }
+      if (deleteTaskAttemptDirectories(ctx.channel(), taskAttemptFailedQ, jobQ, dagIdQ, mapIds)) {
+        return;
+      }
       if (mapIds == null || reduceRange == null || jobQ == null || dagIdQ == null) {
         sendError(ctx, "Required param job, dag, map and reduce", BAD_REQUEST);
         return;
@@ -1112,14 +1127,24 @@ public class ShuffleHandler extends AuxiliaryService {
       ch.writeAndFlush(LastHttpContent.EMPTY_LAST_CONTENT);
     }
 
+    private boolean isNullOrEmpty(List<String> entries) {
+      return entries == null || entries.isEmpty();
+    }
+
+    private boolean notEmptyAndContains(List<String> entries, String key) {
+      if (entries == null || entries.isEmpty()) {
+        return false;
+      }
+      return entries.get(0).contains(key);
+    }
+
     private boolean deleteDagDirectories(Channel channel,
                                          List<String> dagCompletedQ, List<String> jobQ,
                                          List<String> dagIdQ) {
       if (jobQ == null || jobQ.isEmpty()) {
         return false;
       }
-      if (dagCompletedQ != null && !dagCompletedQ.isEmpty() && dagCompletedQ.get(0).contains("delete")
-          && dagIdQ != null && !dagIdQ.isEmpty()) {
+      if (notEmptyAndContains(dagCompletedQ,"delete") && !isNullOrEmpty(dagIdQ)) {
         String base = getDagLocation(jobQ.get(0), dagIdQ.get(0), userRsrc.get(jobQ.get(0)));
         try {
           FileContext lfc = FileContext.getLocalFSFileContext();
@@ -1136,6 +1161,59 @@ public class ShuffleHandler extends AuxiliaryService {
       return false;
     }
 
+    private boolean deleteVertexDirectories(Channel channel, List<String> vertexCompletedQ,
+                                            List<String> jobQ, List<String> dagIdQ,
+                                            List<String> vertexIdQ) {
+      if (jobQ == null || jobQ.isEmpty()) {
+        return false;
+      }
+      if (notEmptyAndContains(vertexCompletedQ, "delete") && !isNullOrEmpty(vertexIdQ)) {
+        try {
+          deleteTaskDirsOfVertex(jobQ.get(0), dagIdQ.get(0), vertexIdQ.get(0), userRsrc.get(jobQ.get(0)));
+        } catch (IOException e) {
+          LOG.warn("Encountered exception during vertex delete " + e);
+        }
+        channel.writeAndFlush(new DefaultHttpResponse(HTTP_1_1, OK))
+                .addListener(ChannelFutureListener.CLOSE);
+        return true;
+      }
+      return false;
+    }
+
+    private boolean deleteTaskAttemptDirectories(Channel channel, List<String> taskAttemptFailedQ,
+                                            List<String> jobQ, List<String> dagIdQ, List<String> taskAttemptIdQ) {
+      if (jobQ == null || jobQ.isEmpty()) {
+        return false;
+      }
+      if (notEmptyAndContains(taskAttemptFailedQ,"delete") && !isNullOrEmpty(taskAttemptIdQ)) {
+        for (String taskAttemptId : taskAttemptIdQ) {
+          String baseStr = getBaseLocation(jobQ.get(0), dagIdQ.get(0), userRsrc.get(jobQ.get(0)));
+          try {
+            FileSystem fs = FileSystem.getLocal(conf).getRaw();
+            for (Path basePath : lDirAlloc.getAllLocalPathsToRead(baseStr, conf)) {
+              for (FileStatus fileStatus : fs.listStatus(basePath)) {
+                Path taskAttemptPath = fileStatus.getPath();
+                if (taskAttemptPath.getName().startsWith(taskAttemptId)) {
+                  if (fs.delete(taskAttemptPath, true)) {
+                    LOG.info("Deleted directory : " + taskAttemptPath);
+                    // remove entry from IndexCache
+                    indexCache.removeMap(taskAttemptPath.getName());
+                    break;
+                  }
+                }
+              }
+            }
+          } catch (IOException e) {
+            LOG.warn("Encountered exception during failed task attempt delete " + e);
+          }
+        }
+        channel.writeAndFlush(new DefaultHttpResponse(HTTP_1_1, OK))
+                .addListener(ChannelFutureListener.CLOSE);
+        return true;
+      }
+      return false;
+    }
+
     /**
      * Calls sendMapOutput for the mapId pointed by ReduceContext.mapsToSend
      * and increments it. This method is first called by channelRead()
@@ -1203,6 +1281,29 @@ public class ShuffleHandler extends AuxiliaryService {
       return baseStr;
     }
 
+    /**
+     * Delete shuffle data in task directories belonging to a vertex.
+     */
+    private void deleteTaskDirsOfVertex(String jobId, String dagId, String vertexId, String user) throws IOException {
+      String baseStr = getBaseLocation(jobId, dagId, user);
+      FileContext lfc = FileContext.getLocalFSFileContext();
+      for(Path dagPath : lDirAlloc.getAllLocalPathsToRead(baseStr, conf)) {
+        RemoteIterator<FileStatus> status = lfc.listStatus(dagPath);
+        final JobID jobID = JobID.forName(jobId);
+        String taskDirPrefix = String.format("attempt%s_%s_%s_",
+            jobID.toString().replace("job", ""), dagId, vertexId);
+        while (status.hasNext()) {
+          FileStatus fileStatus = status.next();
+          Path attemptPath = fileStatus.getPath();
+          if (attemptPath.getName().startsWith(taskDirPrefix)) {
+            if(lfc.delete(attemptPath, true)) {
+              LOG.debug("deleted shuffle data in task directory: {}", attemptPath);
+            }
+          }
+        }
+      }
+    }
+
     private String getDagLocation(String jobId, String dagId, String user) {
       final JobID jobID = JobID.forName(jobId);
       final ApplicationId appID =
@@ -1446,7 +1547,6 @@ public class ShuffleHandler extends AuxiliaryService {
     protected void sendError(ChannelHandlerContext ctx, String message, HttpResponseStatus status) {
       FullHttpResponse response = new DefaultFullHttpResponse(HTTP_1_1, status);
       sendError(ctx, message, response);
-      response.release();
     }
 
     protected void sendError(ChannelHandlerContext ctx, String message, FullHttpResponse response) {
@@ -1464,7 +1564,6 @@ public class ShuffleHandler extends AuxiliaryService {
       header.write(out);
 
       sendError(ctx, wrappedBuffer(out.getData(), 0, out.getLength()), fullResponse);
-      fullResponse.release();
     }
 
     protected void sendError(ChannelHandlerContext ctx, ByteBuf content,
@@ -1479,6 +1578,11 @@ public class ShuffleHandler extends AuxiliaryService {
 
       // Close the connection as soon as the error message is sent.
       ctx.channel().writeAndFlush(response).addListener(ChannelFutureListener.CLOSE);
+      /*
+       * The general rule of thumb is that the party that accesses a reference-counted object last
+       * is also responsible for the destruction of that reference-counted object.
+       */
+      content.release();
     }
 
     @Override
