@@ -32,7 +32,6 @@ import org.apache.tez.common.ATSConstants;
 import org.apache.tez.dag.api.EdgeProperty;
 import org.apache.tez.dag.api.TezUncheckedException;
 import org.apache.tez.dag.api.oldrecords.TaskAttemptState;
-import org.apache.tez.dag.api.oldrecords.TaskState;
 import org.apache.tez.dag.api.records.DAGProtos.CallerContextProto;
 import org.apache.tez.dag.app.web.AMWebController;
 import org.apache.tez.dag.history.HistoryEvent;
@@ -288,7 +287,7 @@ public class HistoryEventTimelineConversion {
 
   private static TimelineEntity convertDAGFinishedEvent(DAGFinishedEvent event) {
     TimelineEntity atsEntity = new TimelineEntity();
-    atsEntity.setEntityId(event.getDagID().toString());
+    atsEntity.setEntityId(event.getDAGID().toString());
     atsEntity.setEntityType(EntityTypes.TEZ_DAG_ID.name());
 
     TimelineEvent finishEvt = new TimelineEvent();
@@ -298,7 +297,7 @@ public class HistoryEventTimelineConversion {
 
     atsEntity.addPrimaryFilter(ATSConstants.USER, event.getUser());
     atsEntity.addPrimaryFilter(ATSConstants.APPLICATION_ID,
-        event.getDagID().getApplicationId().toString());
+        event.getApplicationId().toString());
     atsEntity.addPrimaryFilter(ATSConstants.DAG_NAME, event.getDagName());
     atsEntity.addPrimaryFilter(ATSConstants.STATUS, event.getState().name());
     if (event.getDAGPlan().hasCallerContext()
@@ -327,10 +326,10 @@ public class HistoryEventTimelineConversion {
 
   private static TimelineEntity convertDAGFinishedToDAGExtraInfoEntity(DAGFinishedEvent event) {
     TimelineEntity atsEntity = new TimelineEntity();
-    atsEntity.setEntityId(event.getDagID().toString());
+    atsEntity.setEntityId(event.getDAGID().toString());
     atsEntity.setEntityType(EntityTypes.TEZ_DAG_EXTRA_INFO.name());
 
-    atsEntity.addRelatedEntity(EntityTypes.TEZ_DAG_ID.name(), event.getDagID().toString());
+    atsEntity.addRelatedEntity(EntityTypes.TEZ_DAG_ID.name(), event.getDAGID().toString());
 
     TimelineEvent submitEvt = new TimelineEvent();
     submitEvt.setEventType(HistoryEventType.DAG_FINISHED.name());
@@ -345,7 +344,7 @@ public class HistoryEventTimelineConversion {
 
   private static TimelineEntity convertDAGInitializedEvent(DAGInitializedEvent event) {
     TimelineEntity atsEntity = new TimelineEntity();
-    atsEntity.setEntityId(event.getDagID().toString());
+    atsEntity.setEntityId(event.getDAGID().toString());
     atsEntity.setEntityType(EntityTypes.TEZ_DAG_ID.name());
 
     TimelineEvent initEvt = new TimelineEvent();
@@ -355,13 +354,13 @@ public class HistoryEventTimelineConversion {
 
     atsEntity.addPrimaryFilter(ATSConstants.USER, event.getUser());
     atsEntity.addPrimaryFilter(ATSConstants.APPLICATION_ID,
-        event.getDagID().getApplicationId().toString());
+        event.getApplicationId().toString());
     atsEntity.addPrimaryFilter(ATSConstants.DAG_NAME, event.getDagName());
 
     atsEntity.addOtherInfo(ATSConstants.INIT_TIME, event.getInitTime());
 
     if (event.getVertexNameIDMap() != null) {
-      Map<String, String> nameIdStrMap = new TreeMap<String, String>();
+      Map<String, String> nameIdStrMap = new TreeMap<>();
       for (Entry<String, TezVertexID> entry : event.getVertexNameIDMap().entrySet()) {
         nameIdStrMap.put(entry.getKey(), entry.getValue().toString());
       }
@@ -373,7 +372,7 @@ public class HistoryEventTimelineConversion {
 
   private static TimelineEntity convertDAGStartedEvent(DAGStartedEvent event) {
     TimelineEntity atsEntity = new TimelineEntity();
-    atsEntity.setEntityId(event.getDagID().toString());
+    atsEntity.setEntityId(event.getDAGID().toString());
     atsEntity.setEntityType(EntityTypes.TEZ_DAG_ID.name());
 
     TimelineEvent startEvt = new TimelineEvent();
@@ -383,7 +382,7 @@ public class HistoryEventTimelineConversion {
 
     atsEntity.addPrimaryFilter(ATSConstants.USER, event.getUser());
     atsEntity.addPrimaryFilter(ATSConstants.APPLICATION_ID,
-        event.getDagID().getApplicationId().toString());
+        event.getApplicationId().toString());
     atsEntity.addPrimaryFilter(ATSConstants.DAG_NAME, event.getDagName());
 
     atsEntity.addOtherInfo(ATSConstants.START_TIME, event.getStartTime());
@@ -394,7 +393,7 @@ public class HistoryEventTimelineConversion {
 
   private static TimelineEntity convertDAGSubmittedEvent(DAGSubmittedEvent event) {
     TimelineEntity atsEntity = new TimelineEntity();
-    atsEntity.setEntityId(event.getDagID().toString());
+    atsEntity.setEntityId(event.getDAGID().toString());
     atsEntity.setEntityType(EntityTypes.TEZ_DAG_ID.name());
 
     atsEntity.addRelatedEntity(EntityTypes.TEZ_APPLICATION.name(),
@@ -412,7 +411,7 @@ public class HistoryEventTimelineConversion {
     atsEntity.addPrimaryFilter(ATSConstants.USER, event.getUser());
     atsEntity.addPrimaryFilter(ATSConstants.DAG_NAME, event.getDAGName());
     atsEntity.addPrimaryFilter(ATSConstants.APPLICATION_ID,
-        event.getDagID().getApplicationId().toString());
+        event.getApplicationId().toString());
 
     if (event.getDAGPlan().hasCallerContext()
         && event.getDAGPlan().getCallerContext().hasCallerId()) {
@@ -450,10 +449,10 @@ public class HistoryEventTimelineConversion {
 
   private static TimelineEntity convertDAGSubmittedToDAGExtraInfoEntity(DAGSubmittedEvent event) {
     TimelineEntity atsEntity = new TimelineEntity();
-    atsEntity.setEntityId(event.getDagID().toString());
+    atsEntity.setEntityId(event.getDAGID().toString());
     atsEntity.setEntityType(EntityTypes.TEZ_DAG_EXTRA_INFO.name());
 
-    atsEntity.addRelatedEntity(EntityTypes.TEZ_DAG_ID.name(), event.getDagID().toString());
+    atsEntity.addRelatedEntity(EntityTypes.TEZ_DAG_ID.name(), event.getDAGID().toString());
 
     TimelineEvent submitEvt = new TimelineEvent();
     submitEvt.setEventType(HistoryEventType.DAG_SUBMITTED.name());
@@ -477,13 +476,13 @@ public class HistoryEventTimelineConversion {
     atsEntity.setEntityType(EntityTypes.TEZ_TASK_ATTEMPT_ID.name());
 
     atsEntity.addPrimaryFilter(ATSConstants.APPLICATION_ID,
-        event.getTaskAttemptID().getTaskID().getVertexID().getDAGId().getApplicationId().toString());
+        event.getApplicationId().toString());
     atsEntity.addPrimaryFilter(EntityTypes.TEZ_DAG_ID.name(),
-        event.getTaskAttemptID().getTaskID().getVertexID().getDAGId().toString());
+        event.getDAGID().toString());
     atsEntity.addPrimaryFilter(EntityTypes.TEZ_VERTEX_ID.name(),
-        event.getTaskAttemptID().getTaskID().getVertexID().toString());
+        event.getVertexID().toString());
     atsEntity.addPrimaryFilter(EntityTypes.TEZ_TASK_ID.name(),
-        event.getTaskAttemptID().getTaskID().toString());
+        event.getTaskID().toString());
 
     TimelineEvent finishEvt = new TimelineEvent();
     finishEvt.setEventType(HistoryEventType.TASK_ATTEMPT_FINISHED.name());
@@ -542,16 +541,16 @@ public class HistoryEventTimelineConversion {
     atsEntity.setStartTime(event.getStartTime());
 
     atsEntity.addRelatedEntity(EntityTypes.TEZ_TASK_ID.name(),
-        event.getTaskAttemptID().getTaskID().toString());
+        event.getTaskID().toString());
 
     atsEntity.addPrimaryFilter(ATSConstants.APPLICATION_ID,
-        event.getTaskAttemptID().getTaskID().getVertexID().getDAGId().getApplicationId().toString());
+        event.getApplicationId().toString());
     atsEntity.addPrimaryFilter(EntityTypes.TEZ_DAG_ID.name(),
-        event.getTaskAttemptID().getTaskID().getVertexID().getDAGId().toString());
+        event.getDAGID().toString());
     atsEntity.addPrimaryFilter(EntityTypes.TEZ_VERTEX_ID.name(),
-        event.getTaskAttemptID().getTaskID().getVertexID().toString());
+        event.getVertexID().toString());
     atsEntity.addPrimaryFilter(EntityTypes.TEZ_TASK_ID.name(),
-        event.getTaskAttemptID().getTaskID().toString());
+        event.getTaskID().toString());
 
     TimelineEvent startEvt = new TimelineEvent();
     startEvt.setEventType(HistoryEventType.TASK_ATTEMPT_STARTED.name());
@@ -579,11 +578,11 @@ public class HistoryEventTimelineConversion {
     atsEntity.setEntityType(EntityTypes.TEZ_TASK_ID.name());
 
     atsEntity.addPrimaryFilter(ATSConstants.APPLICATION_ID,
-        event.getTaskID().getVertexID().getDAGId().getApplicationId().toString());
+        event.getApplicationId().toString());
     atsEntity.addPrimaryFilter(EntityTypes.TEZ_DAG_ID.name(),
-        event.getTaskID().getVertexID().getDAGId().toString());
+        event.getDAGID().toString());
     atsEntity.addPrimaryFilter(EntityTypes.TEZ_VERTEX_ID.name(),
-        event.getTaskID().getVertexID().toString());
+        event.getVertexID().toString());
 
     TimelineEvent finishEvt = new TimelineEvent();
     finishEvt.setEventType(HistoryEventType.TASK_FINISHED.name());
@@ -614,14 +613,14 @@ public class HistoryEventTimelineConversion {
     atsEntity.setEntityType(EntityTypes.TEZ_TASK_ID.name());
 
     atsEntity.addRelatedEntity(EntityTypes.TEZ_VERTEX_ID.name(),
-        event.getTaskID().getVertexID().toString());
+        event.getVertexID().toString());
 
     atsEntity.addPrimaryFilter(ATSConstants.APPLICATION_ID,
-        event.getTaskID().getVertexID().getDAGId().getApplicationId().toString());
+        event.getApplicationId().toString());
     atsEntity.addPrimaryFilter(EntityTypes.TEZ_DAG_ID.name(),
-        event.getTaskID().getVertexID().getDAGId().toString());
+        event.getDAGID().toString());
     atsEntity.addPrimaryFilter(EntityTypes.TEZ_VERTEX_ID.name(),
-        event.getTaskID().getVertexID().toString());
+        event.getVertexID().toString());
 
     TimelineEvent startEvt = new TimelineEvent();
     startEvt.setEventType(HistoryEventType.TASK_STARTED.name());
@@ -643,9 +642,9 @@ public class HistoryEventTimelineConversion {
     atsEntity.setEntityType(EntityTypes.TEZ_VERTEX_ID.name());
 
     atsEntity.addPrimaryFilter(ATSConstants.APPLICATION_ID,
-        event.getVertexID().getDAGId().getApplicationId().toString());
+        event.getApplicationId().toString());
     atsEntity.addPrimaryFilter(EntityTypes.TEZ_DAG_ID.name(),
-        event.getVertexID().getDAGId().toString());
+        event.getDAGID().toString());
 
     TimelineEvent finishEvt = new TimelineEvent();
     finishEvt.setEventType(HistoryEventType.VERTEX_FINISHED.name());
@@ -685,12 +684,12 @@ public class HistoryEventTimelineConversion {
     atsEntity.setEntityType(EntityTypes.TEZ_VERTEX_ID.name());
 
     atsEntity.addRelatedEntity(EntityTypes.TEZ_DAG_ID.name(),
-        event.getVertexID().getDAGId().toString());
+        event.getDAGID().toString());
 
     atsEntity.addPrimaryFilter(ATSConstants.APPLICATION_ID,
-        event.getVertexID().getDAGId().getApplicationId().toString());
+        event.getApplicationId().toString());
     atsEntity.addPrimaryFilter(EntityTypes.TEZ_DAG_ID.name(),
-        event.getVertexID().getDAGId().toString());
+        event.getDAGID().toString());
 
     TimelineEvent initEvt = new TimelineEvent();
     initEvt.setEventType(HistoryEventType.VERTEX_INITIALIZED.name());
@@ -718,9 +717,9 @@ public class HistoryEventTimelineConversion {
     atsEntity.setEntityType(EntityTypes.TEZ_VERTEX_ID.name());
 
     atsEntity.addPrimaryFilter(ATSConstants.APPLICATION_ID,
-        event.getVertexID().getDAGId().getApplicationId().toString());
+        event.getApplicationId().toString());
     atsEntity.addPrimaryFilter(EntityTypes.TEZ_DAG_ID.name(),
-        event.getVertexID().getDAGId().toString());
+        event.getDAGID().toString());
 
     TimelineEvent startEvt = new TimelineEvent();
     startEvt.setEventType(HistoryEventType.VERTEX_STARTED.name());
@@ -741,17 +740,17 @@ public class HistoryEventTimelineConversion {
     atsEntity.setEntityType(EntityTypes.TEZ_VERTEX_ID.name());
 
     atsEntity.addPrimaryFilter(ATSConstants.APPLICATION_ID,
-        event.getVertexID().getDAGId().getApplicationId().toString());
+        event.getApplicationId().toString());
     atsEntity.addPrimaryFilter(EntityTypes.TEZ_DAG_ID.name(),
-        event.getVertexID().getDAGId().toString());
+        event.getDAGID().toString());
 
     TimelineEvent updateEvt = new TimelineEvent();
     updateEvt.setEventType(HistoryEventType.VERTEX_CONFIGURE_DONE.name());
     updateEvt.setTimestamp(event.getReconfigureDoneTime());
 
-    Map<String,Object> eventInfo = new HashMap<String, Object>();
+    Map<String,Object> eventInfo = new HashMap<>();
     if (event.getSourceEdgeProperties() != null && !event.getSourceEdgeProperties().isEmpty()) {
-      Map<String, Object> updatedEdgeManagers = new HashMap<String, Object>();
+      Map<String, Object> updatedEdgeManagers = new HashMap<>();
       for (Entry<String, EdgeProperty> entry :
           event.getSourceEdgeProperties().entrySet()) {
         updatedEdgeManagers.put(entry.getKey(),
