@@ -19,6 +19,8 @@
 package org.apache.tez.runtime.task;
 
 import java.io.IOException;
+import java.lang.management.ManagementFactory;
+import java.lang.management.MemoryMXBean;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
@@ -136,6 +138,7 @@ public class TaskReporter implements TaskReporterInterface {
 
     private static final int LOG_COUNTER_START_INTERVAL = 5000; // 5 seconds
     private static final float LOG_COUNTER_BACKOFF = 1.3f;
+    private static final int HEAP_MEMORY_USAGE_UPDATE_INTERVAL = 5000; // 5 seconds
 
     private final RuntimeTask task;
     private final EventMetaData updateEventMetadata;
@@ -157,6 +160,10 @@ public class TaskReporter implements TaskReporterInterface {
     private final ReentrantLock lock = new ReentrantLock();
     private final Condition condition = lock.newCondition();
 
+    private final MemoryMXBean memoryMXBean = ManagementFactory.getMemoryMXBean();
+    private long usedMemory = 0;
+    private long heapMemoryUsageUpdatedTime = System.currentTimeMillis() - HEAP_MEMORY_USAGE_UPDATE_INTERVAL;
+
     /*
      * Keeps track of regular timed heartbeats. Is primarily used as a timing mechanism to send /
      * log counters.
@@ -263,7 +270,7 @@ public class TaskReporter implements TaskReporterInterface {
       int fromPreRoutedEventId = task.getNextPreRoutedEventId();
       int maxEvents = Math.min(maxEventsToGet, task.getMaxEventsToHandle());
       TezHeartbeatRequest request = new TezHeartbeatRequest(requestId, events, fromPreRoutedEventId,
-          containerIdStr, task.getTaskAttemptID(), fromEventId, maxEvents);
+          containerIdStr, task.getTaskAttemptID(), fromEventId, maxEvents, getUsedMemory());
       LOG.debug("Sending heartbeat to AM, request={}", request);
 
       maybeLogCounters();
@@ -305,6 +312,15 @@ public class TaskReporter implements TaskReporterInterface {
       return new ResponseWrapper(false, numEventsReceived);
     }
 
+    private long getUsedMemory() {
+      long now = System.currentTimeMillis();
+      if (now - heapMemoryUsageUpdatedTime > HEAP_MEMORY_USAGE_UPDATE_INTERVAL) {
+        usedMemory = memoryMXBean.getHeapMemoryUsage().getUsed();
+        heapMemoryUsageUpdatedTime = now;
+      }
+      return usedMemory;
+    }
+
     public void markComplete() {
       // Notify to clear pending events, if any.
       lock.lock();
