@@ -61,7 +61,6 @@ import org.apache.tez.common.counters.Limits;
 import org.apache.tez.common.security.JobTokenIdentifier;
 import org.apache.tez.common.security.TokenCache;
 import org.apache.tez.dag.api.TezConfiguration;
-import org.apache.tez.dag.api.TezConstants;
 import org.apache.tez.dag.api.TezException;
 import org.apache.tez.dag.api.records.DAGProtos;
 import org.apache.tez.dag.records.TezVertexID;
@@ -72,6 +71,7 @@ import org.apache.tez.runtime.api.ExecutionContext;
 import org.apache.tez.runtime.api.impl.ExecutionContextImpl;
 import org.apache.tez.runtime.common.objectregistry.ObjectRegistryImpl;
 import org.apache.tez.runtime.internals.api.TaskReporterInterface;
+import org.apache.tez.util.TezRuntimeShutdownHandler;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -372,13 +372,12 @@ public class TezChild {
   private void cleanupOnTaskChanged(ContainerTask containerTask) {
     Preconditions.checkState(!containerTask.shouldDie());
     Preconditions.checkState(containerTask.getTaskSpec() != null);
-    TezVertexID newVertexID = containerTask.getTaskSpec().getTaskAttemptID().getTaskID()
-        .getVertexID();
+    TezVertexID newVertexID = containerTask.getTaskSpec().getTaskAttemptID().getVertexID();
     if (lastVertexID != null) {
       if (!lastVertexID.equals(newVertexID)) {
         objectRegistry.clearCache(ObjectRegistryImpl.ObjectLifeCycle.VERTEX);
       }
-      if (!lastVertexID.getDAGId().equals(newVertexID.getDAGId())) {
+      if (!lastVertexID.getDAGID().equals(newVertexID.getDAGID())) {
         objectRegistry.clearCache(ObjectRegistryImpl.ObjectLifeCycle.DAG);
         startedInputsMap = HashMultimap.create();
       }
@@ -392,8 +391,10 @@ public class TezChild {
       LOG.info("Shutting down container {}", containerIdString);
       // It's possible that there's pending tasks on the executor. Those should be cancelled.
       List<Runnable> pendingRunnables = executor.shutdownNow();
+      LOG.info("There are {} runnables in shared executor, cancelling those...", pendingRunnables.size());
       for (Runnable r : pendingRunnables) {
-        LOG.info("Cancelling pending runnables during TezChild shutdown for containerId={}", containerIdString);
+        LOG.info("Cancelling pending runnable ({}) during TezChild shutdown for containerId={}", r.hashCode(),
+            containerIdString);
         ((FutureTask)r).cancel(false);
       }
       if (taskReporter != null) {
@@ -403,6 +404,8 @@ public class TezChild {
         RPC.stopProxy(umbilical);
       }
     }
+    TezRuntimeShutdownHandler.shutdown();
+    LOG.info("TezChild shutdown finished");
   }
 
   public static class ContainerExecutionResult {
@@ -524,7 +527,8 @@ public class TezChild {
         System.getenv(), pid, new ExecutionContextImpl(System.getenv(Environment.NM_HOST.name())),
         credentials, Runtime.getRuntime().maxMemory(), System
             .getenv(ApplicationConstants.Environment.USER.toString()), null, true, hadoopShim);
-    tezChild.run();
+    ContainerExecutionResult result = tezChild.run();
+    LOG.info("TezChild is about to exit from main(), run() returned result: {}", result.toString());
   }
 
   private void handleError(Throwable t) {
