@@ -42,8 +42,10 @@ import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.fs.RawLocalFileSystem;
 import org.apache.hadoop.io.compress.CompressionCodec;
 import org.apache.tez.common.TezRuntimeFrameworkConfigs;
+import org.apache.tez.common.TezUtilsInternal;
 import org.apache.tez.common.counters.TezCounter;
 import org.apache.tez.common.security.JobTokenSecretManager;
+import org.apache.tez.runtime.api.InputContext;
 import org.apache.tez.runtime.library.common.Constants;
 import org.apache.tez.runtime.library.common.InputAttemptIdentifier;
 import org.apache.tez.runtime.library.common.shuffle.orderedgrouped.MapOutput.Type;
@@ -81,7 +83,7 @@ class FetcherOrderedGrouped extends CallableWithNdc<Void> {
   private final int localShufflePort;
   private final String applicationId;
   private final int dagId;
-  private final MapHost mapHost;
+  protected final MapHost mapHost;
 
   private final int minPartition;
   private final int maxPartition;
@@ -121,7 +123,6 @@ class FetcherOrderedGrouped extends CallableWithNdc<Void> {
                                boolean localDiskFetchEnabled,
                                String localHostname,
                                int shufflePort,
-                               String srcNameTrimmed,
                                MapHost mapHost,
                                TezCounter ioErrsCounter,
                                TezCounter wrongLengthErrsCounter,
@@ -129,12 +130,11 @@ class FetcherOrderedGrouped extends CallableWithNdc<Void> {
                                TezCounter wrongMapErrsCounter,
                                TezCounter connectionErrsCounter,
                                TezCounter wrongReduceErrsCounter,
-                               String applicationId,
-                               int dagId,
                                boolean asyncHttp,
                                boolean sslShuffle,
                                boolean verifyDiskChecksum,
-                               boolean compositeFetch) {
+                               boolean compositeFetch,
+                               InputContext inputContext) {
     this.scheduler = scheduler;
     this.allocator = allocator;
     this.exceptionReporter = exceptionReporter;
@@ -149,8 +149,8 @@ class FetcherOrderedGrouped extends CallableWithNdc<Void> {
     this.badIdErrs = badIdErrsCounter;
     this.connectionErrs = connectionErrsCounter;
     this.wrongReduceErrs = wrongReduceErrsCounter;
-    this.applicationId = applicationId;
-    this.dagId = dagId;
+    this.applicationId = inputContext.getApplicationId().toString();
+    this.dagId = inputContext.getDagIdentifier();
 
     this.ifileReadAhead = ifileReadAhead;
     this.ifileReadAheadLength = ifileReadAheadLength;
@@ -171,7 +171,9 @@ class FetcherOrderedGrouped extends CallableWithNdc<Void> {
     this.verifyDiskChecksum = verifyDiskChecksum;
     this.compositeFetch = compositeFetch;
 
-    this.logIdentifier = "fetcher [" + srcNameTrimmed + "] #" + id;
+    String sourceDestNameTrimmed = TezUtilsInternal.cleanVertexName(inputContext.getSourceVertexName()) + " -> "
+        + TezUtilsInternal.cleanVertexName(inputContext.getTaskVertexName());
+    this.logIdentifier = "fetcher [" + sourceDestNameTrimmed + "] #" + id;
   }
 
   @VisibleForTesting
@@ -350,8 +352,7 @@ class FetcherOrderedGrouped extends CallableWithNdc<Void> {
         LOG.debug("Detected fetcher has been shutdown after connection establishment. Returning");
         return false;
       }
-      input = httpConnection.getInputStream();
-      httpConnection.validate();
+      setupConnectionInternal(host, attempts);
       return true;
     } catch (IOException | InterruptedException ie) {
       if (ie instanceof InterruptedException) {
@@ -378,13 +379,19 @@ class FetcherOrderedGrouped extends CallableWithNdc<Void> {
       for (InputAttemptIdentifier left : remaining.values()) {
         // Need to be handling temporary glitches ..
         // Report read error to the AM to trigger source failure heuristics
-        scheduler.copyFailed(InputAttemptFetchFailure.fromAttempt(left), host, connectSucceeded,
+        scheduler.copyFailed(InputAttemptFetchFailure.fromAttempt(left).withCause(ie), host, connectSucceeded,
             !connectSucceeded);
       }
       return false;
     }
   }
 
+  protected void setupConnectionInternal(MapHost host, Collection<InputAttemptIdentifier> attempts)
+      throws IOException, InterruptedException {
+    input = httpConnection.getInputStream();
+    httpConnection.validate();
+  }
+
   @VisibleForTesting
   protected void putBackRemainingMapOutputs(MapHost host) {
     // Cycle through remaining MapOutputs
@@ -426,7 +433,7 @@ class FetcherOrderedGrouped extends CallableWithNdc<Void> {
   }
 
   protected InputAttemptFetchFailure[] copyMapOutput(MapHost host, DataInputStream input,
-      InputAttemptIdentifier inputAttemptIdentifier) throws FetcherReadTimeoutException {
+      InputAttemptIdentifier inputAttemptIdentifier) throws FetcherReadTimeoutException, IOException {
     MapOutput mapOutput = null;
     InputAttemptIdentifier srcAttemptId = null;
     long decompressedLength = 0;
@@ -738,7 +745,7 @@ class FetcherOrderedGrouped extends CallableWithNdc<Void> {
             if (!stopped) {
               hasFailures = true;
               ioErrs.increment(1);
-              scheduler.copyFailed(InputAttemptFetchFailure.fromLocalFetchFailure(srcAttemptId),
+              scheduler.copyFailed(InputAttemptFetchFailure.fromLocalFetchFailure(srcAttemptId).withCause(e),
                   host, true, false);
               LOG.warn("Failed to read local disk output of " + srcAttemptId + " from " +
                   host.getHostIdentifier(), e);
