@@ -178,6 +178,7 @@ class ShuffleScheduler {
   private final Referee referee;
   @VisibleForTesting
   final Map<InputAttemptIdentifier, IntWritable> failureCounts = new HashMap<InputAttemptIdentifier,IntWritable>();
+
   final Set<HostPort> uniqueHosts = Sets.newHashSet();
   private final Map<HostPort,IntWritable> hostFailures = new HashMap<HostPort,IntWritable>();
   private final InputContext inputContext;
@@ -221,8 +222,6 @@ class ShuffleScheduler {
   private final boolean localDiskFetchEnabled;
   private final String localHostname;
   private final int shufflePort;
-  private final String applicationId;
-  private final int dagId;
   private final boolean asyncHttp;
   private final boolean sslShuffle;
 
@@ -247,7 +246,7 @@ class ShuffleScheduler {
   private final boolean checkFailedFetchSinceLastCompletion;
   private final boolean verifyDiskChecksum;
   private final boolean compositeFetch;
-
+  private final boolean enableFetcherTestingErrors;
   private volatile Thread shuffleSchedulerThread = null;
   private final int maxPenaltyTime;
 
@@ -337,8 +336,6 @@ class ShuffleScheduler {
             TezRuntimeConfiguration
                 .TEZ_RUNTIME_SHUFFLE_FAILED_CHECK_SINCE_LAST_COMPLETION_DEFAULT);
 
-    this.applicationId = inputContext.getApplicationId().toString();
-    this.dagId = inputContext.getDagIdentifier();
     this.localHostname = inputContext.getExecutionContext().getHostName();
     String auxiliaryService = conf.get(TezConfiguration.TEZ_AM_SHUFFLE_AUXILIARY_SERVICE_ID,
         TezConfiguration.TEZ_AM_SHUFFLE_AUXILIARY_SERVICE_ID_DEFAULT);
@@ -426,6 +423,10 @@ class ShuffleScheduler {
     this.maxPenaltyTime = conf.getInt(TezRuntimeConfiguration.TEZ_RUNTIME_SHUFFLE_HOST_PENALTY_TIME_LIMIT_MS,
         TezRuntimeConfiguration.TEZ_RUNTIME_SHUFFLE_HOST_PENALTY_TIME_LIMIT_MS_DEFAULT);
 
+    this.enableFetcherTestingErrors =
+        conf.getBoolean(TezRuntimeConfiguration.TEZ_RUNTIME_SHUFFLE_FETCH_ENABLE_TESTING_ERRORS,
+            TezRuntimeConfiguration.TEZ_RUNTIME_SHUFFLE_FETCH_ENABLE_TESTING_ERRORS_DEFAULT);
+
     pipelinedShuffleInfoEventsMap = Maps.newConcurrentMap();
     LOG.info("ShuffleScheduler running for sourceVertex: "
         + inputContext.getSourceVertexName() + " with configuration: "
@@ -442,6 +443,7 @@ class ShuffleScheduler {
         + ", minReqProgressFraction=" + minReqProgressFraction
         + ", checkFailedFetchSinceLastCompletion=" + checkFailedFetchSinceLastCompletion
         + ", asyncHttp=" + asyncHttp
+        + ", enableFetcherTestingErrors=" + enableFetcherTestingErrors
     );
   }
 
@@ -667,7 +669,7 @@ class ShuffleScheduler {
 
       if (remainingMaps.get() == 0) {
         notifyAll(); // Notify the getHost() method.
-        LOG.info("All inputs fetched for input vertex : " + inputContext.getSourceVertexName());
+        LOG.info("All inputs fetched for input vertex : " + inputContext.getInputOutputVertexNames());
       }
 
       // update the status
@@ -792,7 +794,7 @@ class ShuffleScheduler {
     }
 
     //Restart consumer in case shuffle is not healthy
-    if (!isShuffleHealthy(fetchFailure.getInputAttemptIdentifier())) {
+    if (!isShuffleHealthy(fetchFailure)) {
       return;
     }
 
@@ -884,7 +886,7 @@ class ShuffleScheduler {
                     srcAttempt.getInputIdentifier(), srcAttempt.getAttemptNumber())
                 + " to jobtracker.",
             srcAttempt.getInputIdentifier(), srcAttempt.getAttemptNumber(),
-            fetchFailure.isLocalFetch(), fetchFailure.isDiskErrorAtSource()));
+            fetchFailure.isLocalFetch(), fetchFailure.isDiskErrorAtSource(), localHostname));
 
     inputContext.sendEvents(failedEvents);
   }
@@ -1006,8 +1008,8 @@ class ShuffleScheduler {
     return fetcherHealthy;
   }
 
-  boolean isShuffleHealthy(InputAttemptIdentifier srcAttempt) {
-
+  boolean isShuffleHealthy(InputAttemptFetchFailure fetchFailure) {
+    InputAttemptIdentifier srcAttempt = fetchFailure.getInputAttemptIdentifier();
     if (isAbortLimitExceeedFor(srcAttempt)) {
       return false;
     }
@@ -1044,18 +1046,20 @@ class ShuffleScheduler {
         && !fetcherHealthy
         && (!reducerProgressedEnough || reducerStalled)) {
       String errorMsg = (srcNameTrimmed + ": "
-          + "Shuffle failed with too many fetch failures and insufficient progress!"
-          + "failureCounts=" + failureCounts.size()
+          + "Shuffle failed with too many fetch failures and insufficient progress: "
+          + "[failureCounts=" + failureCounts.size()
           + ", pendingInputs=" + (numInputs - doneMaps)
           + ", fetcherHealthy=" + fetcherHealthy
           + ", reducerProgressedEnough=" + reducerProgressedEnough
-          + ", reducerStalled=" + reducerStalled);
+          + ", reducerStalled=" + reducerStalled
+          + ", hostFailures=" + hostFailures)
+          + "]";
       LOG.error(errorMsg);
       if (LOG.isDebugEnabled()) {
         LOG.debug("Host failures=" + hostFailures.keySet());
       }
       // Shuffle knows how to deal with failures post shutdown via the onFailure hook
-      exceptionReporter.reportException(new IOException(errorMsg));
+      exceptionReporter.reportException(new IOException(errorMsg, fetchFailure.getCause()));
       return false;
     }
     return true;
@@ -1109,7 +1113,7 @@ class ShuffleScheduler {
       }
       IOException exception = new IOException(srcAttempt + " is marked as obsoleteInput, but it "
           + "exists in shuffleInfoEventMap. Some data could have been already merged "
-          + "to memory/disk outputs.  Failing the fetch early. eventInfo:" + eventInfo.toString());
+          + "to memory/disk outputs. Failing the fetch early. eventInfo: " + eventInfo);
       String message = "Got obsolete event. Killing self as attempt's data could have been consumed";
       killSelf(exception, message);
       return;
@@ -1379,7 +1383,7 @@ class ShuffleScheduler {
             } catch (InterruptedException e) {
               if (isShutdown.get()) {
                 LOG.info(srcNameTrimmed + ": " +
-                    "Interrupted while waiting for fetchers to complete" +
+                    "Interrupted while waiting for fetchers to complete " +
                     "and hasBeenShutdown. Breaking out of ShuffleSchedulerCallable loop");
                 Thread.currentThread().interrupt();
                 break;
@@ -1463,12 +1467,21 @@ class ShuffleScheduler {
 
   @VisibleForTesting
   FetcherOrderedGrouped constructFetcherForHost(MapHost mapHost) {
-    return new FetcherOrderedGrouped(httpConnectionParams, ShuffleScheduler.this, allocator,
-        exceptionReporter, jobTokenSecretManager, ifileReadAhead, ifileReadAheadLength,
-        codec, conf, localFs, localDiskFetchEnabled, localHostname, shufflePort, srcNameTrimmed, mapHost,
-        ioErrsCounter, wrongLengthErrsCounter, badIdErrsCounter, wrongMapErrsCounter,
-        connectionErrsCounter, wrongReduceErrsCounter, applicationId, dagId, asyncHttp, sslShuffle,
-        verifyDiskChecksum, compositeFetch);
+    if (enableFetcherTestingErrors) {
+      return new FetcherOrderedGroupedWithInjectableErrors(httpConnectionParams, ShuffleScheduler.this, allocator,
+          exceptionReporter, jobTokenSecretManager, ifileReadAhead, ifileReadAheadLength,
+          codec, conf, localFs, localDiskFetchEnabled, localHostname, shufflePort, mapHost,
+          ioErrsCounter, wrongLengthErrsCounter, badIdErrsCounter, wrongMapErrsCounter,
+          connectionErrsCounter, wrongReduceErrsCounter, asyncHttp, sslShuffle,
+          verifyDiskChecksum, compositeFetch, inputContext);
+    } else {
+      return new FetcherOrderedGrouped(httpConnectionParams, ShuffleScheduler.this, allocator,
+          exceptionReporter, jobTokenSecretManager, ifileReadAhead, ifileReadAheadLength,
+          codec, conf, localFs, localDiskFetchEnabled, localHostname, shufflePort, mapHost,
+          ioErrsCounter, wrongLengthErrsCounter, badIdErrsCounter, wrongMapErrsCounter,
+          connectionErrsCounter, wrongReduceErrsCounter, asyncHttp, sslShuffle,
+          verifyDiskChecksum, compositeFetch, inputContext);
+    }
   }
 
   private class FetchFutureCallback implements FutureCallback<Void> {
