@@ -23,22 +23,25 @@ import java.io.DataOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
+import java.nio.ByteBuffer;
 import java.util.Iterator;
 import java.util.concurrent.atomic.AtomicBoolean;
 
 import com.google.common.annotations.VisibleForTesting;
 
+import org.apache.hadoop.io.BoundedByteArrayOutputStream;
+import org.apache.tez.runtime.library.common.task.local.output.TezTaskOutput;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.apache.hadoop.classification.InterfaceAudience;
 import org.apache.hadoop.classification.InterfaceStability;
-import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FSDataOutputStream;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.io.DataInputBuffer;
 import org.apache.hadoop.io.DataOutputBuffer;
 import org.apache.tez.runtime.library.utils.BufferUtils;
+import org.apache.tez.runtime.library.utils.CodecUtils;
 import org.apache.hadoop.io.IOUtils;
 import org.apache.hadoop.io.WritableUtils;
 import org.apache.hadoop.io.compress.CodecPool;
@@ -46,7 +49,7 @@ import org.apache.hadoop.io.compress.CompressionCodec;
 import org.apache.hadoop.io.compress.CompressionOutputStream;
 import org.apache.hadoop.io.compress.Compressor;
 import org.apache.hadoop.io.compress.Decompressor;
-import org.apache.hadoop.io.serializer.SerializationFactory;
+import org.apache.hadoop.io.serializer.Serialization;
 import org.apache.hadoop.io.serializer.Serializer;
 import org.apache.tez.common.counters.TezCounter;
 
@@ -71,6 +74,197 @@ public class IFile {
   private static final String INCOMPLETE_READ = "Requested to read %d got %d";
   private static final String REQ_BUFFER_SIZE_TOO_LARGE = "Size of data %d is greater than the max allowed of %d";
 
+  /**
+   * IFileWriter which stores data in memory for specified limit, beyond
+   * which it falls back to file based writer. It creates files lazily on
+   * need basis and avoids any disk hit (in cases, where data fits entirely in mem).
+   * <p>
+   * This class should not make any changes to IFile logic and should just flip streams
+   * from mem to disk on need basis.
+   *
+   * During write, it verifies whether uncompressed payload can fit in memory. If so, it would
+   * store in buffer. Otherwise, it falls back to file based writer. Note that data stored
+   * internally would be in compressed format (if codec is provided). However, for easier
+   * comparison and spill over, uncompressed payload check is done. This is
+   * done intentionally, as it is not possible to know compressed data length
+   * upfront.
+   */
+  public static class FileBackedInMemIFileWriter extends Writer {
+
+    private FileSystem fs;
+    private boolean bufferFull;
+
+    // For lazy creation of file
+    private TezTaskOutput taskOutput;
+    private int totalSize;
+
+    private Path outputPath;
+    private CompressionCodec fileCodec;
+    private BoundedByteArrayOutputStream cacheStream;
+
+    private static final int checksumSize = IFileOutputStream.getCheckSumSize();
+
+    /**
+     * Note that we do not allow compression in in-mem stream.
+     * When spilled over to file, compression gets enabled.
+     *
+     * @param keySerialization
+     * @param valSerialization
+     * @param fs
+     * @param taskOutput
+     * @param keyClass
+     * @param valueClass
+     * @param codec
+     * @param writesCounter
+     * @param serializedBytesCounter
+     * @param cacheSize
+     * @throws IOException
+     */
+    public FileBackedInMemIFileWriter(Serialization<?> keySerialization,
+        Serialization<?> valSerialization, FileSystem fs, TezTaskOutput taskOutput,
+        Class<?> keyClass, Class<?> valueClass, CompressionCodec codec, TezCounter writesCounter,
+        TezCounter serializedBytesCounter, int cacheSize) throws IOException {
+      super(keySerialization, valSerialization, new FSDataOutputStream(createBoundedBuffer(cacheSize), null),
+          keyClass, valueClass, null, writesCounter, serializedBytesCounter);
+      this.fs = fs;
+      this.cacheStream = (BoundedByteArrayOutputStream) this.rawOut.getWrappedStream();
+      this.taskOutput = taskOutput;
+      this.bufferFull = (cacheStream == null);
+      this.totalSize = getBaseCacheSize();
+      this.fileCodec = codec;
+    }
+
+    /**
+     * For basic cache size checks: header + checksum + EOF marker
+     *
+     * @return size of the base cache needed
+     */
+    static int getBaseCacheSize() {
+      return (HEADER.length + checksumSize
+          + (2 * WritableUtils.getVIntSize(EOF_MARKER)));
+    }
+
+    boolean shouldWriteToDisk() {
+      return totalSize >= cacheStream.getLimit();
+    }
+
+    /**
+     * Create in mem stream. In it is too small, adjust it's size
+     *
+     * @param size
+     * @return in memory stream
+     */
+    public static BoundedByteArrayOutputStream createBoundedBuffer(int size) {
+      int resize = Math.max(getBaseCacheSize(), size);
+      return new BoundedByteArrayOutputStream(resize);
+    }
+
+    /**
+     * Flip over from memory to file based writer.
+     *
+     * 1. Content format: HEADER + real data + CHECKSUM. Checksum is for real
+     * data.
+     * 2. Before flipping, close checksum stream, so that checksum is written
+     * out.
+     * 3. Create relevant file based writer.
+     * 4. Write header and then real data.
+     *
+     * @throws IOException
+     */
+    private void resetToFileBasedWriter() throws IOException {
+      // Close out stream, so that data checksums are written.
+      // Buf contents = HEADER + real data + CHECKSUM
+      this.out.close();
+
+      // Get the buffer which contains data in memory
+      BoundedByteArrayOutputStream bout =
+          (BoundedByteArrayOutputStream) this.rawOut.getWrappedStream();
+
+      // Create new file based writer
+      if (outputPath == null) {
+        outputPath = taskOutput.getOutputFileForWrite();
+      }
+      LOG.info("Switching from mem stream to disk stream. File: " + outputPath);
+      FSDataOutputStream newRawOut = fs.create(outputPath);
+      this.rawOut = newRawOut;
+      this.ownOutputStream = true;
+
+      setupOutputStream(fileCodec);
+
+      // Write header to file
+      headerWritten = false;
+      writeHeader(newRawOut);
+
+      // write real data
+      int sPos = HEADER.length;
+      int len = (bout.size() - checksumSize - HEADER.length);
+      this.out.write(bout.getBuffer(), sPos, len);
+
+      bufferFull = true;
+      bout.reset();
+    }
+
+
+    @Override
+    protected void writeKVPair(byte[] keyData, int keyPos, int keyLength,
+        byte[] valueData, int valPos, int valueLength) throws IOException {
+      if (!bufferFull) {
+        // Compute actual payload size: write RLE marker, length info and then entire data.
+        totalSize += ((prevKey == REPEAT_KEY) ? V_END_MARKER_SIZE : 0)
+            + WritableUtils.getVIntSize(keyLength) + keyLength
+            + WritableUtils.getVIntSize(valueLength) + valueLength;
+
+        if (shouldWriteToDisk()) {
+          resetToFileBasedWriter();
+        }
+      }
+      super.writeKVPair(keyData, keyPos, keyLength, valueData, valPos, valueLength);
+    }
+
+    @Override
+    protected void writeValue(byte[] data, int offset, int length) throws IOException {
+      if (!bufferFull) {
+        totalSize += ((prevKey != REPEAT_KEY) ? RLE_MARKER_SIZE : 0)
+            + WritableUtils.getVIntSize(length) + length;
+
+        if (shouldWriteToDisk()) {
+          resetToFileBasedWriter();
+        }
+      }
+      super.writeValue(data, offset, length);
+    }
+
+    /**
+     * Check if data was flushed to disk.
+     *
+     * @return whether data is flushed to disk ot not
+     */
+    public boolean isDataFlushedToDisk() {
+      return bufferFull;
+    }
+
+    /**
+     * Get cached data if any
+     *
+     * @return if data is not flushed to disk, it returns in-mem contents
+     */
+    public ByteBuffer getData() {
+      if (!isDataFlushedToDisk()) {
+        return ByteBuffer.wrap(cacheStream.getBuffer(), 0, cacheStream.size());
+      }
+      return null;
+    }
+
+    @VisibleForTesting
+    void setOutputPath(Path outputPath) {
+      this.outputPath = outputPath;
+    }
+
+    public Path getOutputPath() {
+      return this.outputPath;
+    }
+  }
+
   /**
    * <code>IFile.Writer</code> to write out intermediate map-outputs.
    */
@@ -118,12 +312,12 @@ public class IFile {
     protected final boolean rle;
 
 
-    public Writer(Configuration conf, FileSystem fs, Path file,
+    public Writer(Serialization keySerialization, Serialization valSerialization, FileSystem fs, Path file,
                   Class keyClass, Class valueClass,
                   CompressionCodec codec,
                   TezCounter writesCounter,
                   TezCounter serializedBytesCounter) throws IOException {
-      this(conf, fs.create(file), keyClass, valueClass, codec,
+      this(keySerialization, valSerialization, fs.create(file), keyClass, valueClass, codec,
            writesCounter, serializedBytesCounter);
       ownOutputStream = true;
     }
@@ -134,28 +328,45 @@ public class IFile {
       this.rle = rle;
     }
 
-    public Writer(Configuration conf, FSDataOutputStream outputStream,
+    public Writer(Serialization keySerialization, Serialization valSerialization, FSDataOutputStream outputStream,
         Class keyClass, Class valueClass, CompressionCodec codec, TezCounter writesCounter,
         TezCounter serializedBytesCounter) throws IOException {
-      this(conf, outputStream, keyClass, valueClass, codec, writesCounter,
+      this(keySerialization, valSerialization, outputStream, keyClass, valueClass, codec, writesCounter,
           serializedBytesCounter, false);
     }
 
-    public Writer(Configuration conf, FSDataOutputStream outputStream,
-        Class keyClass, Class valueClass,
-        CompressionCodec codec, TezCounter writesCounter, TezCounter serializedBytesCounter,
-        boolean rle) throws IOException {
+    public Writer(Serialization keySerialization, Serialization valSerialization, FSDataOutputStream outputStream,
+                  Class keyClass, Class valueClass,
+                  CompressionCodec codec, TezCounter writesCounter, TezCounter serializedBytesCounter,
+                  boolean rle) throws IOException {
       this.rawOut = outputStream;
       this.writtenRecordsCounter = writesCounter;
       this.serializedUncompressedBytes = serializedBytesCounter;
-      this.checksumOut = new IFileOutputStream(outputStream);
       this.start = this.rawOut.getPos();
       this.rle = rle;
+
+      setupOutputStream(codec);
+
+      writeHeader(outputStream);
+
+      if (keyClass != null) {
+        this.closeSerializers = true;
+        this.keySerializer = keySerialization.getSerializer(keyClass);
+        this.keySerializer.open(buffer);
+        this.valueSerializer = valSerialization.getSerializer(valueClass);
+        this.valueSerializer.open(buffer);
+      } else {
+        this.closeSerializers = false;
+      }
+    }
+
+    void setupOutputStream(CompressionCodec codec) throws IOException {
+      this.checksumOut = new IFileOutputStream(this.rawOut);
       if (codec != null) {
-        this.compressor = CodecPool.getCompressor(codec);
+        this.compressor = CodecUtils.getCompressor(codec);
         if (this.compressor != null) {
           this.compressor.reset();
-          this.compressedOut = codec.createOutputStream(checksumOut, compressor);
+          this.compressedOut = CodecUtils.createOutputStream(codec, checksumOut, compressor);
           this.out = new FSDataOutputStream(this.compressedOut,  null);
           this.compressOutput = true;
         } else {
@@ -165,23 +376,10 @@ public class IFile {
       } else {
         this.out = new FSDataOutputStream(checksumOut,null);
       }
-      writeHeader(outputStream);
-
-      if (keyClass != null) {
-        this.closeSerializers = true;
-        SerializationFactory serializationFactory =
-          new SerializationFactory(conf);
-        this.keySerializer = serializationFactory.getSerializer(keyClass);
-        this.keySerializer.open(buffer);
-        this.valueSerializer = serializationFactory.getSerializer(valueClass);
-        this.valueSerializer.open(buffer);
-      } else {
-        this.closeSerializers = false;
-      }
     }
 
-    public Writer(Configuration conf, FileSystem fs, Path file) throws IOException {
-      this(conf, fs, file, null, null, null, null, null);
+    public Writer(Serialization keySerialization, Serialization valSerialization, FileSystem fs, Path file) throws IOException {
+      this(keySerialization, valSerialization, fs, file, null, null, null, null, null);
     }
 
     protected void writeHeader(OutputStream outputStream) throws IOException {
@@ -575,9 +773,9 @@ public class IFile {
         checksumIn = new IFileInputStream(in, length, readAhead,
             readAheadLength/* , isCompressed */);
         if (isCompressed && codec != null) {
-          decompressor = CodecPool.getDecompressor(codec);
+          decompressor = CodecUtils.getDecompressor(codec);
           if (decompressor != null) {
-            this.in = codec.createInputStream(checksumIn, decompressor);
+            this.in = CodecUtils.createInputStream(codec, checksumIn, decompressor);
           } else {
             LOG.warn("Could not obtain decompressor from CodecPool");
             this.in = checksumIn;
@@ -620,10 +818,11 @@ public class IFile {
       in = checksumIn;
       Decompressor decompressor = null;
       if (isCompressed && codec != null) {
-        decompressor = CodecPool.getDecompressor(codec);
+        decompressor = CodecUtils.getDecompressor(codec);
         if (decompressor != null) {
           decompressor.reset();
-          in = codec.createInputStream(checksumIn, decompressor);
+          in = CodecUtils.getDecompressedInputStreamWithBufferSize(codec, checksumIn, decompressor,
+              compressedLength);
         } else {
           LOG.warn("Could not obtain decompressor from CodecPool");
           in = checksumIn;
@@ -645,9 +844,7 @@ public class IFile {
           try {
             in.close();
           } catch(IOException e) {
-            if(LOG.isDebugEnabled()) {
-              LOG.debug("Exception in closing " + in, e);
-            }
+            LOG.debug("Exception in closing {}", in, e);
           }
         }
         throw ioe;
