@@ -20,14 +20,15 @@ package org.apache.tez.runtime.library.common.shuffle;
 
 import org.apache.hadoop.fs.RawLocalFileSystem;
 import org.apache.tez.runtime.library.common.CompositeInputAttemptIdentifier;
-import static org.mockito.Matchers.anyInt;
-import static org.mockito.Matchers.anyLong;
-import static org.mockito.Matchers.anyString;
-import static org.mockito.Matchers.eq;
+
 import static org.mockito.Mockito.any;
+import static org.mockito.Mockito.anyInt;
+import static org.mockito.Mockito.anyLong;
+import static org.mockito.Mockito.anyString;
 import static org.mockito.Mockito.doAnswer;
 import static org.mockito.Mockito.doNothing;
 import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.eq;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.spy;
@@ -81,7 +82,7 @@ public class TestFetcher {
     final boolean DISABLE_LOCAL_FETCH = false;
 
     Fetcher.FetcherBuilder builder = new Fetcher.FetcherBuilder(fetcherCallback, null, null,
-        ApplicationId.newInstance(0, 1), 1, null, "fetcherTest", conf, ENABLE_LOCAL_FETCH, HOST,
+        createMockInputContext(), null, conf, ENABLE_LOCAL_FETCH, HOST,
         PORT, false, true, false);
     builder.assignWork(HOST, PORT, 0, 1, Arrays.asList(srcAttempts));
     Fetcher fetcher = spy(builder.build());
@@ -100,7 +101,7 @@ public class TestFetcher {
 
     // when enabled and hostname does not match use http fetch.
     builder = new Fetcher.FetcherBuilder(fetcherCallback, null, null,
-        ApplicationId.newInstance(0, 1), -1, null, "fetcherTest", conf, ENABLE_LOCAL_FETCH, HOST,
+        createMockInputContext(), null, conf, ENABLE_LOCAL_FETCH, HOST,
         PORT, false, true, false);
     builder.assignWork(HOST + "_OTHER", PORT, 0, 1, Arrays.asList(srcAttempts));
     fetcher = spy(builder.build());
@@ -116,7 +117,7 @@ public class TestFetcher {
 
     // when enabled and port does not match use http fetch.
     builder = new Fetcher.FetcherBuilder(fetcherCallback, null, null,
-        ApplicationId.newInstance(0, 1), -1, null, "fetcherTest", conf, ENABLE_LOCAL_FETCH, HOST,
+        createMockInputContext(), null, conf, ENABLE_LOCAL_FETCH, HOST,
         PORT, false, true, false);
     builder.assignWork(HOST, PORT + 1, 0, 1, Arrays.asList(srcAttempts));
     fetcher = spy(builder.build());
@@ -133,7 +134,7 @@ public class TestFetcher {
     // When disabled use http fetch
     conf.setBoolean(TezRuntimeConfiguration.TEZ_RUNTIME_OPTIMIZE_LOCAL_FETCH, false);
     builder = new Fetcher.FetcherBuilder(fetcherCallback, null, null,
-        ApplicationId.newInstance(0, 1), 1, null, "fetcherTest", conf, DISABLE_LOCAL_FETCH, HOST,
+        createMockInputContext(), null, conf, DISABLE_LOCAL_FETCH, HOST,
         PORT, false, true, false);
     builder.assignWork(HOST, PORT, 0, 1, Arrays.asList(srcAttempts));
     fetcher = spy(builder.build());
@@ -167,7 +168,7 @@ public class TestFetcher {
     int partition = 42;
     FetcherCallback callback = mock(FetcherCallback.class);
     Fetcher.FetcherBuilder builder = new Fetcher.FetcherBuilder(callback, null, null,
-        ApplicationId.newInstance(0, 1), 1, null, "fetcherTest", conf, true, HOST, PORT,
+        createMockInputContext(), null, conf, true, HOST, PORT,
         false, true, true);
     ArrayList<InputAttemptIdentifier> inputAttemptIdentifiers = new ArrayList<>();
     for(CompositeInputAttemptIdentifier compositeInputAttemptIdentifier : srcAttempts) {
@@ -193,7 +194,7 @@ public class TestFetcher {
         Object[] args = invocation.getArguments();
         return new Path(SHUFFLE_INPUT_FILE_PREFIX + args[0]);
       }
-    }).when(fetcher).getShuffleInputFileName(anyString(), anyString());
+    }).when(fetcher).getShuffleInputFileName(anyString(), any());
 
     doAnswer(new Answer<TezIndexRecord>() {
       @Override
@@ -306,7 +307,7 @@ public class TestFetcher {
     int partition = 42;
     FetcherCallback callback = mock(FetcherCallback.class);
     Fetcher.FetcherBuilder builder = new Fetcher.FetcherBuilder(callback, null, null,
-        ApplicationId.newInstance(0, 1), 1, null, "fetcherTest", conf, true, HOST, PORT,
+        createMockInputContext(), null, conf, true, HOST, PORT,
         false, true, false);
     builder.assignWork(HOST, PORT, partition, 1, Arrays.asList(srcAttempts));
     Fetcher fetcher = spy(builder.build());
@@ -330,7 +331,7 @@ public class TestFetcher {
     doReturn("vertex").when(inputContext).getSourceVertexName();
 
     Fetcher.FetcherBuilder builder = new Fetcher.FetcherBuilder(mock(ShuffleManager.class), null,
-        null, ApplicationId.newInstance(0, 1), 1, null, "fetcherTest", conf, true, HOST, PORT,
+        null, createMockInputContext(), null, conf, true, HOST, PORT,
         false, true, false);
     builder.assignWork(HOST, PORT, 0, 1, Arrays.asList(new InputAttemptIdentifier(0, 0)));
 
@@ -345,4 +346,15 @@ public class TestFetcher {
     Assert.assertTrue(failures[0].isDiskErrorAtSource());
     Assert.assertFalse(failures[0].isLocalFetch());
   }
+
+  private InputContext createMockInputContext() {
+    InputContext inputContext = mock(InputContext.class);
+
+    doReturn(ApplicationId.newInstance(0, 1)).when(inputContext).getApplicationId();
+    doReturn(1).when(inputContext).getDagIdentifier();
+    doReturn("sourceVertex").when(inputContext).getSourceVertexName();
+    doReturn("taskVertex").when(inputContext).getTaskVertexName();
+
+    return inputContext;
+  }
 }
