@@ -28,8 +28,11 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
+import com.google.protobuf.ByteString;
 import org.apache.commons.lang.StringUtils;
+import org.apache.tez.dag.app.dag.impl.ImmediateStartVertexManager;
 import org.apache.tez.dag.app.dag.impl.OneToOneEdgeManagerOnDemand;
+import org.apache.tez.dag.app.dag.impl.RootInputVertexManager;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.apache.hadoop.conf.Configuration;
@@ -65,7 +68,6 @@ import org.apache.tez.dag.api.EdgeProperty.SchedulingType;
 import org.apache.tez.dag.api.client.DAGClient;
 import org.apache.tez.dag.api.client.DAGStatus;
 import org.apache.tez.dag.api.event.VertexStateUpdate;
-import org.apache.tez.dag.app.dag.impl.RootInputVertexManager;
 import org.apache.tez.dag.library.vertexmanager.InputReadyVertexManager;
 import org.apache.tez.runtime.api.AbstractLogicalIOProcessor;
 import org.apache.tez.runtime.api.AbstractLogicalInput;
@@ -114,7 +116,7 @@ public class TestExceptionPropagation {
     try {
       conf.set(MiniDFSCluster.HDFS_MINIDFS_BASEDIR, TEST_ROOT_DIR);
       dfsCluster =
-          new MiniDFSCluster.Builder(conf).numDataNodes(3).format(true)
+          new MiniDFSCluster.Builder(conf).numDataNodes(1).storagesPerDatanode(1).format(true)
               .racks(null).build();
       remoteFs = dfsCluster.getFileSystem();
     } catch (IOException io) {
@@ -125,6 +127,7 @@ public class TestExceptionPropagation {
     Configuration miniTezconf = new Configuration(conf);
     miniTezconf.setInt(YarnConfiguration.RM_AM_MAX_ATTEMPTS, 4);
     miniTezconf.set("fs.defaultFS", remoteFs.getUri().toString()); // use HDFS
+    miniTezconf.setLong(TezConfiguration.TEZ_AM_SLEEP_TIME_BEFORE_EXIT_MILLIS, 500);
     miniTezCluster.init(miniTezconf);
     miniTezCluster.start();
   }
@@ -292,7 +295,6 @@ public class TestExceptionPropagation {
           appReport.getDiagnostics().trim());
     } finally {
       stopNonSessionClient();
-      Thread.sleep(10*1000);
       stopTezMiniCluster();
     }
   }
@@ -343,7 +345,8 @@ public class TestExceptionPropagation {
         InputInitializerWithException.getIIDesc(payload);
     v1.addDataSource("input",
         DataSourceDescriptor.create(inputDesc, iiDesc, null));
-    v1.setVertexManagerPlugin(RootInputVertexManagerWithException.getVMDesc(payload));
+    v1.setVertexManagerPlugin(RootInputVertexManagerWithException
+        .getVMDesc(exLocation));
 
     Vertex v2 = 
         Vertex.create("v2", DoNothingProcessor.getProcDesc(), 1);
@@ -626,7 +629,6 @@ public class TestExceptionPropagation {
       output.start();
       output.getWriter();
 
-      Thread.sleep(3*1000);
       if (this.exLocation == ExceptionLocation.PROCESSOR_RUN_ERROR) {
         throw new Error(this.exLocation.name());
       } else if (this.exLocation == ExceptionLocation.PROCESSOR_RUN_EXCEPTION) {
@@ -671,6 +673,8 @@ public class TestExceptionPropagation {
   public static class RootInputVertexManagerWithException extends RootInputVertexManager {
 
     private ExceptionLocation exLocation;
+    private static final String Test_ExceptionLocation =
+        "Test.ExceptionLocation";
 
     public RootInputVertexManagerWithException(VertexManagerPluginContext context) {
       super(context);
@@ -679,9 +683,15 @@ public class TestExceptionPropagation {
     @Override
     public void initialize() {
       super.initialize();
-      this.exLocation =
-          ExceptionLocation.valueOf(new String(getContext().getUserPayload()
-              .deepCopyAsArray()));
+      Configuration conf;
+      try {
+        conf = TezUtils.createConfFromUserPayload(
+            getContext().getUserPayload());
+        this.exLocation = ExceptionLocation.valueOf(
+            conf.get(Test_ExceptionLocation));
+      } catch (IOException e) {
+        throw new TezUncheckedException(e);
+      }
       if (this.exLocation == ExceptionLocation.VM_INITIALIZE) {
         throw new RuntimeException(this.exLocation.name());
       }
@@ -704,9 +714,22 @@ public class TestExceptionPropagation {
       super.onVertexStarted(completions);
     }
 
-    public static VertexManagerPluginDescriptor getVMDesc(UserPayload payload) {
-      return VertexManagerPluginDescriptor.create(RootInputVertexManagerWithException.class.getName())
-              .setUserPayload(payload);
+    @Override
+    public void onSourceTaskCompleted(TaskAttemptIdentifier attempt) {
+      if (this.exLocation == ExceptionLocation.VM_ON_SOURCETASK_COMPLETED) {
+        throw new RuntimeException(this.exLocation.name());
+      }
+      super.onSourceTaskCompleted(attempt);
+    }
+
+    public static VertexManagerPluginDescriptor getVMDesc(
+        ExceptionLocation exLocation) throws IOException {
+      Configuration conf = new Configuration();
+      conf.set(Test_ExceptionLocation, exLocation.name());
+      UserPayload payload = TezUtils.createUserPayloadFromConf(conf);
+      return VertexManagerPluginDescriptor.create(
+          RootInputVertexManagerWithException.class.getName())
+          .setUserPayload(payload);
     }
   }
 
@@ -845,7 +868,7 @@ public class TestExceptionPropagation {
     }
 
     @Override
-    public EventRouteMetadata routeCompositeDataMovementEventToDestination(
+    public CompositeEventRouteMetadata routeCompositeDataMovementEventToDestination(
         int sourceTaskIndex, int destinationTaskIndex)
         throws Exception {
       if (exLocation == ExceptionLocation.EM_RouteDataMovementEventToDestination) {
